@@ -18,8 +18,7 @@
  */
 
 #include "grid.h"
-#include "stel_utility.h"
-#include "draw.h"
+#include "StelUtils.hpp"
 
 void moy(Vec3f * p, int a, int b, int c)
 {
@@ -770,19 +769,11 @@ int Grid::GetNearest(Vec3f& v)
     return bestI;
 }
 
-void Grid::Draw(void)
-{
-	for(int i=0;i<NbPoints;++i)
-    {
-    	Draw::drawPoint(Points[i][0],Points[i][1],Points[i][2]);
-	}
-}
-
 // Return an array with the number of the zones in the field of view
 int Grid::Intersect(Vec3f pos, float fieldAngle)
 {
 	pos.normalize();
-	float max = cosf(fieldAngle/2.f + Angle);
+	float max = std::cos(fieldAngle/2.f + Angle);
 
 	int nbResult=0;
 	for(int i=0;i<NbPoints;++i)
@@ -795,144 +786,3 @@ int Grid::Intersect(Vec3f pos, float fieldAngle)
 	}
 	return nbResult;
 }
-
-/*
-float tempTab[92][3] ={
-{0.0000,0.0000,1.0000    },
-{0.8944,0.0000,0.4472    },
-{0.2764,0.8507,0.4472    },
-{-0.7236,0.5257,0.4472   },
-{-0.7236,-0.5257,0.4472  },
-{0.2764,-0.8507,0.4472   },
-{0.7236,0.5257,-0.4472   },
-{-0.2764,0.8507,-0.4472  },
-{-0.8944,-0.0000,-0.4472 },
-{-0.2764,-0.8507,-0.4472 },
-{0.7236,-0.5257,-0.4472  },
-{0.0000,0.0000,-1.0000   },
-{0.3607,0.0000,0.9327    },
-{0.6729,0.0000,0.7397    },
-{0.1115,0.3431,0.9327    },
-{0.2079,0.6399,0.7397    },
-{-0.2918,0.2120,0.9327   },
-{-0.5444,0.3955,0.7397   },
-{-0.2918,-0.2120,0.9327  },
-{-0.5444,-0.3955,0.7397  },
-{0.1115,-0.3431,0.9327   },
-{0.2079,-0.6399,0.7397   },
-{0.7844,0.3431,0.5168    },
-{0.5687,0.6399,0.5168    },
-{-0.0839,0.8520,0.5168   },
-{-0.4329,0.7386,0.5168   },
-{-0.8362,0.1835,0.5168   },
-{-0.8362,-0.1835,0.5168  },
-{-0.4329,-0.7386,0.5168  },
-{-0.0839,-0.8520,0.5168  },
-{0.5687,-0.6399,0.5168   },
-{0.7844,-0.3431,0.5168   },
-{0.9647,0.2120,0.1561    },
-{0.9051,0.3955,-0.1561   },
-{0.0965,0.9830,0.1561    },
-{-0.0965,0.9830,-0.1561  },
-{-0.9051,0.3955,0.1561   },
-{-0.9647,0.2120,-0.1561  },
-{-0.6558,-0.7386,0.1561  },
-{-0.4998,-0.8520,-0.1561 },
-{0.4998,-0.8520,0.1561   },
-{0.6558,-0.7386,-0.1561  },
-{0.9647,-0.2120,0.1561   },
-{0.9051,-0.3955,-0.1561  },
-{0.4998,0.8520,0.1561    },
-{0.6558,0.7386,-0.1561   },
-{-0.6558,0.7386,0.1561   },
-{-0.4998,0.8520,-0.1561  },
-{-0.9051,-0.3955,0.1561  },
-{-0.9647,-0.2120,-0.1561 },
-{0.0965,-0.9830,0.1561   },
-{-0.0965,-0.9830,-0.1561 },
-{0.4329,0.7386,-0.5168   },
-{0.0839,0.8520,-0.5168   },
-{-0.5687,0.6399,-0.5168  },
-{-0.7844,0.3431,-0.5168  },
-{-0.7844,-0.3431,-0.5168 },
-{-0.5687,-0.6399,-0.5168 },
-{0.0839,-0.8520,-0.5168  },
-{0.4329,-0.7386,-0.5168  },
-{0.8362,-0.1835,-0.5168  },
-{0.8362,0.1835,-0.5168   },
-{0.2918,0.2120,-0.9327   },
-{0.5444,0.3955,-0.7397   },
-{-0.1115,0.3431,-0.9327  },
-{-0.2079,0.6399,-0.7397  },
-{-0.3607,-0.0000,-0.9327 },
-{-0.6729,-0.0000,-0.7397 },
-{-0.1115,-0.3431,-0.9327 },
-{-0.2079,-0.6399,-0.7397 },
-{0.2918,-0.2120,-0.9327  },
-{0.5444,-0.3955,-0.7397  },
-{0.4795,0.3484,0.8054    },
-{-0.1832,0.5637,0.8054   },
-{-0.5927,-0.0000,0.8054  },
-{-0.1832,-0.5637,0.8054  },
-{0.4795,-0.3484,0.8054   },
-{0.9855,0.0000,-0.1699   },
-{0.3045,0.9372,-0.1699   },
-{-0.7973,0.5792,-0.1699  },
-{-0.7973,-0.5792,-0.1699 },
-{0.3045,-0.9372,-0.1699  },
-{0.7973,0.5792,0.1699    },
-{-0.3045,0.9372,0.1699   },
-{-0.9855,-0.0000,0.1699  },
-{-0.3045,-0.9372,0.1699  },
-{0.7973,-0.5792,0.1699   },
-{0.1832,0.5637,-0.8054   },
-{-0.4795,0.3484,-0.8054  },
-{-0.4795,-0.3484,-0.8054 },
-{0.1832,-0.5637,-0.8054  },
-{0.5927,0.0000,-0.8054   }};
-*/
-/*
-float tempTab[42][3] ={
-{0.0000,0.0000,1.0000   },
-{0.8944,0.0000,0.4472   },
-{0.2764,0.8507,0.4472   },
-{-0.7236,0.5257,0.4472  },
-{-0.7236,-0.5257,0.4472 },
-{0.2764,-0.8507,0.4472  },
-{0.7236,0.5257,-0.4472  },
-{-0.2764,0.8507,-0.4472 },
-{-0.8944,-0.0000,-0.4472},
-{-0.2764,-0.8507,-0.4472},
-{0.7236,-0.5257,-0.4472 },
-{0.0000,0.0000,-1.0000  },
-{0.5257,0.0000,0.8507   },
-{0.1625,0.5000,0.8507   },
-{-0.4253,0.3090,0.8507  },
-{-0.4253,-0.3090,0.8507 },
-{0.1625,-0.5000,0.8507  },
-{0.6882,0.5000,0.5257   },
-{-0.2629,0.8090,0.5257  },
-{-0.8507,-0.0000,0.5257 },
-{-0.2629,-0.8090,0.5257 },
-{0.6882,-0.5000,0.5257  },
-{0.9511,0.3090,0.0000   },
-{-0.0000,1.0000,0.0000  },
-{-0.9511,0.3090,0.0000  },
-{-0.5878,-0.8090,0.0000 },
-{0.5878,-0.8090,0.0000  },
-{0.9511,-0.3090,0.0000  },
-{0.5878,0.8090,0.0000   },
-{-0.5878,0.8090,0.0000  },
-{-0.9511,-0.3090,0.0000 },
-{0.0000,-1.0000,0.0000  },
-{0.2629,0.8090,-0.5257  },
-{-0.6882,0.5000,-0.5257 },
-{-0.6882,-0.5000,-0.5257},
-{0.2629,-0.8090,-0.5257 },
-{0.8507,0.0000,-0.5257  },
-{0.4253,0.3090,-0.8507  },
-{-0.1625,0.5000,-0.8507 },
-{-0.5257,-0.0000,-0.8507},
-{-0.1625,-0.5000,-0.8507},
-{0.4253,-0.3090,-0.8507 }};
-*/
