@@ -21,6 +21,10 @@
 
 #include <iostream>
 #include "image.h"
+#include "StelApp.hpp"
+#include "StelTextureMgr.hpp"
+#include "Projector.hpp"
+#include "Navigator.hpp"
 
 Image::Image( string filename, string name, IMAGE_POSITIONING pos_type) {
   flag_alpha = flag_scale = flag_location = flag_rotation = 0;
@@ -31,11 +35,9 @@ Image::Image( string filename, string name, IMAGE_POSITIONING pos_type) {
   image_scale = 1;
   image_name = name;
 
-  // load image using alpha channel in image, otherwise no transparency
-  // other than through set_alpha method -- could allow alpha load option from command 
-
-  image_tex = new s_texture(1, filename, TEX_LOAD_TYPE_PNG_ALPHA);  // what if it doesn't load?
-  //  image_tex = new s_texture(1, filename, TEX_LOAD_TYPE_PNG_BLEND3);  // black = transparent
+  // use alpha channel if present, otherwise use solid texture
+  StelApp::getInstance().getTextureManager().setDefaultParams();
+  image_tex = StelApp::getInstance().getTextureManager().createTexture(filename);  // what if it doesn't load?
 
   int img_w, img_h;
   image_tex->getDimensions(img_w, img_h);
@@ -48,7 +50,6 @@ Image::Image( string filename, string name, IMAGE_POSITIONING pos_type) {
 }
 
 Image::~Image() {
-  if(image_tex) delete image_tex;
 }
 
 void Image::set_alpha(float alpha, float duration) {
@@ -111,7 +112,7 @@ void Image::set_location( float xpos, bool deltax, float ypos, bool deltay, floa
 }
 
 
-bool Image::update(int delta_time) {
+bool Image::update(double delta_time) {
 
   if(image_ratio < 0) return 0;
 
@@ -187,12 +188,15 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 
   glColor4f(1.0,1.0,1.0,image_alpha);
 
-  glBindTexture(GL_TEXTURE_2D, image_tex->getID());
+  // printf("image_alpha %f\n", image_alpha);
+
+  image_tex->bind();
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
   float cx = vieww/2.f + prj->getViewportPosX();
   float cy = viewh/2.f + prj->getViewportPosY();
 
+
   // calculations to keep image proportions when scale up to fit view
   float prj_ratio = (float)vieww/viewh;   
 
@@ -208,7 +212,6 @@ void Image::draw(const Navigator * nav, Projector * prj) {
   float w = image_scale*xbase;
   float h = image_scale*ybase;
 
-
   if(image_pos_type == POS_VIEWPORT ) {
 
 	  //	  cout << "drawing image viewport " << image_name << endl;
@@ -216,34 +219,17 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 	  // at x or y = 1, image is centered on projection edge
 	  // centered in viewport at 0,0
 
-	  prj->set_orthographic_projection();	// set 2D coordinate
+	  // printf("Image drawn: %f %f %f %f\n", cx+image_xpos*vieww/2,cy+image_ypos*viewh/2, w, h);
 
-	  glTranslatef(cx+image_xpos*vieww/2,cy+image_ypos*viewh/2,0);  // rotate around center of image...
-	  glRotatef(image_rotation,0,0,-1);
+	  prj->drawRectSprite2dMode(cx+image_xpos*vieww/2,cy+image_ypos*viewh/2, 2*w, 2*h, -image_rotation);
 
-	  glBegin(GL_TRIANGLE_STRIP); {
-		  glTexCoord2i(1,0);              // Bottom Right
-		  glVertex3f(w,-h,0);
-		  glTexCoord2i(0,0);              // Bottom Left
-		  glVertex3f(-w,-h,0);
-		  glTexCoord2i(1,1);              // Top Right
-		  glVertex3f(w,h,0);
-		  glTexCoord2i(0,1);              // Top Left
-		  glVertex3f(-w,h,0); }
-	  glEnd();
-	  
-	  prj->reset_perspective_projection();
 
   } else if(image_pos_type == POS_HORIZONTAL ) {
 
 	  //	  cout << "drawing image horizontal " << image_name << endl;
 
 	  // alt az coords
-	  prj->reset_perspective_projection();
-
-	  nav->switch_to_local();
-	  Mat4d mat = nav->get_local_to_eye_mat();
-
+	  prj->setCurrentFrame(Projector::FRAME_LOCAL);
 	  Vec3d gridpt;
 	  
 	  //	  printf("%f %f\n", image_xpos, image_ypos);
@@ -269,20 +255,20 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 				  // TODO: separate x, y scales?
 				  if(image_ratio<1) {
 					  // image height is maximum angular dimension
-					  gridpt = Mat4d::rotation( imagev, (image_rotation+180)*M_PI/180.) *
+					  gridpt = Mat4d::rotation( imagev, (image_rotation)*M_PI/180.) *
 						  Mat4d::rotation( ortho1, image_scale*(j-grid_size/2.)/(float)grid_size*M_PI/180.) *
 						  Mat4d::rotation( ortho2, image_scale/image_ratio*(i+k-grid_size/2.)/(float)grid_size*M_PI/180.) *
 						  imagev;
 
 				  } else {
 					  // image width is maximum angular dimension
-					  gridpt = Mat4d::rotation( imagev, (image_rotation+180)*M_PI/180.) *
+					  gridpt = Mat4d::rotation( imagev, (image_rotation)*M_PI/180.) *
 						  Mat4d::rotation( ortho1, image_scale/image_ratio*(j-grid_size/2.)/(float)grid_size*M_PI/180.) *
 						  Mat4d::rotation( ortho2, image_scale*(i+k-grid_size/2.)/(float)grid_size*M_PI/180.) *
 						  imagev;
 				  }
 				  glTexCoord2f((i+k)/(float)grid_size,j/(float)grid_size);
-				  prj->sVertex3( gridpt[0], gridpt[1], gridpt[2], mat);
+				  prj->drawVertex3v(gridpt);
 			  }
 		  }
 
@@ -292,11 +278,18 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 
   } else if(image_pos_type == POS_J2000 || image_pos_type == POS_EQUATORIAL) {
 
+	if(image_pos_type == POS_J2000)
+	{
+		prj->setCurrentFrame(Projector::FRAME_J2000);
+	}
+	else if (image_pos_type == POS_EQUATORIAL)
+	{
+		prj->setCurrentFrame(Projector::FRAME_EARTH_EQU);
+	}
+	
 	  // equatorial is in current equatorial coordinates
 	  // j2000 is in J2000 epoch equatorial coordinates (precessed)
 
-	  prj->set_orthographic_projection();    // 2D coordinate
-
 	  Vec3d gridpt, onscreen;
 
 	  // ypos is right ascension, xpos is declination
@@ -333,8 +326,7 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 						  imagev;
 				  }
 
-				  if((image_pos_type == POS_J2000 && prj->project_j2000(gridpt, onscreen)) ||
-					 (image_pos_type == POS_EQUATORIAL && prj->project_earth_equ(gridpt, onscreen))) {
+				  if(prj->project(gridpt, onscreen)) {
 
 					  glTexCoord2f((i+k)/(float)grid_size,j/(float)grid_size);
 			  
@@ -346,8 +338,6 @@ void Image::draw(const Navigator * nav, Projector * prj) {
 
 		  glEnd();  
 	  }
-	
-	  prj->reset_perspective_projection();
 	  
 	  
   }
