@@ -17,27 +17,38 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-// manages images for display from scripts
 
 #ifndef _IMAGE_MGR_H_
 #define _IMAGE_MGR_H_
 
 #include <vector>
 #include <string>
+#include "StelModule.hpp"
 #include "image.h"
+/**
+ * Manage images displayed at the request of the command interface (scripts)
+ * @author Robert Spearman <rob@digitaliseducation.com>
+ */
 
-class ImageMgr
+
+class ImageMgr : public StelModule
 {
 
 public:
     ImageMgr();
     virtual ~ImageMgr();
+    
+	///////////////////////////////////////////////////////////////////////////
+	// Methods defined in the StelModule class
+	virtual void init(const InitParser& conf, LoadingBar& lb) {return;}
+	virtual string getModuleID() const { return "image_mgr"; }
+	virtual double draw(Projector *prj, const Navigator *nav, ToneReproducer *eye);
+	virtual void update(double deltaTime);
+	
     int load_image(string filename, string name, Image::IMAGE_POSITIONING position_type);
     int drop_image(string name);
     int drop_all_images();
     Image *get_image(string name);
-    void update(int delta_time);  // update properties
-    void draw(const Navigator * nav, Projector * prj);
 
 private:
     vector<Image*> active_images;
