@@ -20,18 +20,15 @@
 #include <iostream>
 #include <sstream>
 #include <fstream>
-#include "SDL_timer.h"
 #include "s_gui.h"
-#include "stel_utility.h"
-#if !defined(powf)
-#include "fmath.h"
-#endif
+#include "StelUtils.hpp"
+#include "STexture.hpp"
 using namespace std;
 using namespace s_gui;
 
 EditBox * EditBox::activeEditBox = NULL;
 		
-void glCircle(const Vec3d& pos, float radius, float line_width)
+void glCircleGui(const Vec3d& pos, float radius, float line_width)
 {
 	float angle, facets;
 	bool lastState = glIsEnabled(GL_TEXTURE_2D);
@@ -222,13 +219,12 @@ void Scissor::pop(void)
 ////////////////////////////////////////////////////////////////////////////////
 
 Painter::Painter() :
-	tex1(NULL),
 	font(NULL),
 	opaque(false)
 {
 }
 
-Painter::Painter(const s_texture* _tex1, s_font* _font,
+Painter::Painter(const STextureSP _tex1, SFont* _font,
 	const s_color& _baseColor, const s_color& _textColor) :
 		tex1(_tex1),
 		font(_font),
@@ -279,7 +275,7 @@ void Painter::drawSquareFill(const s_vec2i& pos, const s_vec2i& sz) const
 	if (opaque) glDisable(GL_BLEND);
 	else glEnable(GL_BLEND);
 
-    glBindTexture(GL_TEXTURE_2D, tex1->getID());
+    tex1->bind();
     glBegin(GL_QUADS );
         glTexCoord2s(0, 0); glVertex2i(pos[0]        , pos[1] + sz[1]);	// Bottom Left
         glTexCoord2s(1, 0); glVertex2i(pos[0] + sz[0], pos[1] + sz[1]);	// Bottom Right
@@ -298,7 +294,7 @@ void Painter::drawSquareFill(const s_vec2i& pos, const s_vec2i& sz, const s_colo
 	//else 
 	glEnable(GL_BLEND);
 
-    glBindTexture(GL_TEXTURE_2D, tex1->getID());
+    tex1->bind();
     glBegin(GL_QUADS );
         glTexCoord2s(0, 0); glVertex2i(pos[0]        , pos[1] + sz[1]);	// Bottom Left
         glTexCoord2s(1, 0); glVertex2i(pos[0] + sz[0], pos[1] + sz[1]);	// Bottom Right
@@ -309,14 +305,14 @@ void Painter::drawSquareFill(const s_vec2i& pos, const s_vec2i& sz, const s_colo
 
 // Fill the defined square with the given texture and given color
 void Painter::drawSquareFill(const s_vec2i& pos, const s_vec2i& sz,
-                             const s_color& c, const s_texture * t) const
+                             const s_color& c, const STextureSP t) const
 {
     glColor4fv(c);
     glEnable(GL_TEXTURE_2D);
 
 	glEnable(GL_BLEND);
 
-    glBindTexture(GL_TEXTURE_2D, t->getID());
+    t->bind();
     glBegin(GL_QUADS );
         glTexCoord2s(0, 0); glVertex2i(pos[0]        , pos[1] + sz[1]);	// Bottom Left
         glTexCoord2s(1, 0); glVertex2i(pos[0] + sz[0], pos[1] + sz[1]);	// Bottom Right
@@ -468,22 +464,22 @@ CallbackComponent::CallbackComponent() : Component(), is_mouse_over(false), pres
 {
 }
 
-bool CallbackComponent::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool CallbackComponent::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 	pressed = false;
-	if (state==S_GUI_PRESSED && bt==S_GUI_MOUSE_LEFT && isIn(x, y))
+	if (state==Stel_MOUSEBUTTONDOWN && bt==Stel_BUTTON_LEFT && isIn(x, y))
 	{
 		pressed = true;
 	}
-	if (state==S_GUI_RELEASED && bt==S_GUI_MOUSE_LEFT && isIn(x, y))
+	if (state==Stel_MOUSEBUTTONUP && bt==Stel_BUTTON_LEFT && isIn(x, y))
 	{
 		if (!onPressCallback.empty()) RUNCALLBACK(onPressCallback);
 	}
 	return false;
 }
 
-bool CallbackComponent::onMove(int x, int y)
+bool CallbackComponent::onMove(int x, int y, StelMod mod)
 {
 	if (!visible) 
 	{
@@ -678,7 +674,7 @@ void Container::draw(void)
 	}
 }
 
-bool Container::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
+bool Container::onClic(int x, int y, Uint8 button, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 
@@ -692,7 +688,7 @@ bool Container::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 		if ((*iter)->getFocus())	
 		{
 			hasFocus = true;
-			if ((*iter)->onClic(x - pos[0], y - pos[1], button, state)) 
+			if ((*iter)->onClic(x - pos[0], y - pos[1], button, state, mod)) 
 			{
 				// The signal has been intercepted
 				// Set the component in first position in the objects list
@@ -709,7 +705,7 @@ bool Container::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 	iter = childs.begin();
 	while (iter != childs.end())
 	{
-		if ((*iter)->onClic(x - pos[0], y - pos[1], button, state))
+		if ((*iter)->onClic(x - pos[0], y - pos[1], button, state, mod))
 		{
 			// The signal has been intercepted
 			// Set the component in first position in the objects list
@@ -719,10 +715,10 @@ bool Container::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 		}
         iter++;
     }
-	return CallbackComponent::onClic(x, y, button, state);
+	return CallbackComponent::onClic(x, y, button, state, mod);
 }
 
-bool Container::onMove(int x, int y)
+bool Container::onMove(int x, int y, StelMod mod)
 {
 	bool hasFocus = false;
 
@@ -735,24 +731,24 @@ bool Container::onMove(int x, int y)
 		if ((*iter)->getFocus())	
 		{
 			hasFocus = true;
-			if ((*iter)->onMove(x - pos[0], y - pos[1])) return true;
+			if ((*iter)->onMove(x - pos[0], y - pos[1], mod)) return true;
 		}
         iter++;
 	}
 	// focus but not handled - return
-	if (hasFocus) return CallbackComponent::onMove(x, y);
+	if (hasFocus) return CallbackComponent::onMove(x, y, mod);
 	
 	iter = childs.begin();
 
 	while (iter != childs.end())
 	{
-		if ((*iter)->onMove(x - pos[0], y - pos[1])) return true;	// The signal has been intercepted
+		if ((*iter)->onMove(x - pos[0], y - pos[1], mod)) return true;	// The signal has been intercepted
         iter++;
     }
-	return CallbackComponent::onMove(x, y);
+	return CallbackComponent::onMove(x, y, mod);
 }
 
-bool Container::onKey(Uint16 k, S_GUI_VALUE s)
+bool Container::onKey(Uint16 k, Uint8 s, StelMod mod)
 {
 	bool hasFocus = false;
 	if (!visible) return false;
@@ -765,7 +761,7 @@ bool Container::onKey(Uint16 k, S_GUI_VALUE s)
 		if ((*iter)->getFocus())	
 		{
 			hasFocus = true;
-			if ((*iter)->onKey(k,s)) return true;
+			if ((*iter)->onKey(k,s, mod)) return true;
 		}
         iter++;
 	}
@@ -775,7 +771,7 @@ bool Container::onKey(Uint16 k, S_GUI_VALUE s)
 	iter = childs.begin();
 	while (iter != childs.end())
 	{
-		if ((*iter)->onKey(k, s)) return 1;	// The signal has been intercepted
+		if ((*iter)->onKey(k, s, mod)) return 1;	// The signal has been intercepted
         iter++;
     }
     return false;
@@ -813,7 +809,6 @@ Button::Button() :
 void Button::draw()
 {
 	if (!visible) return;
-
 	if (!is_mouse_over)
 	{
 		if (!hideBorder)
@@ -826,12 +821,12 @@ void Button::draw()
 	}
 }
 
-bool Button::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool Button::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 
-	CallbackComponent::onClic(x,y,bt,state);
-	if (bt==S_GUI_MOUSE_LEFT && isIn(x, y)) return 1;
+	CallbackComponent::onClic(x,y,bt,state, mod);
+	if (bt==Stel_BUTTON_LEFT && isIn(x, y)) return 1;
 	return 0;
 }
 
@@ -847,7 +842,7 @@ void FilledButton::draw()
 ////////////////////////////////////////////////////////////////////////////////
 
 
-TexturedButton::TexturedButton(const s_texture* tex)
+TexturedButton::TexturedButton(const STextureSP tex)
 {
 	if (tex) setTexture(tex);
 }
@@ -873,12 +868,12 @@ void CheckBox::draw()
 	Button::draw();
 }
 
-bool CheckBox::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool CheckBox::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
-	if (state==S_GUI_RELEASED && bt==S_GUI_MOUSE_LEFT && isIn(x, y))
+	if (state==Stel_MOUSEBUTTONUP && bt==Stel_BUTTON_LEFT && isIn(x, y))
 		isChecked = !isChecked;
-	return Button::onClic(x,y,bt,state);
+	return Button::onClic(x,y,bt,state, mod);
 }
 
 LabeledCheckBox::LabeledCheckBox(bool state, const wstring& _label) : 
@@ -909,17 +904,15 @@ void LabeledCheckBox::draw(void)
 	Container::draw();
 }
 
-FlagButton::FlagButton(int state, const s_texture* tex,
-                       const string& specificTexName) : CheckBox(state)
+FlagButton::FlagButton(int state, const STextureSP tex, STextureSP specificTex) : CheckBox(state)
 {
 	if (tex) setTexture(tex);
-	if (!specificTexName.empty()) specific_tex = new s_texture(specificTexName);
+	specific_tex = specificTex;
 	setSize(24,24);
 }
 
 FlagButton::~FlagButton()
 {
-	if (specific_tex) delete specific_tex;
 }
 
 void FlagButton::draw()
@@ -943,7 +936,7 @@ void FlagButton::draw()
 // Text label
 ////////////////////////////////////////////////////////////////////////////////
 
-Label::Label(const wstring& _label, s_font * _font)
+Label::Label(const wstring& _label, SFont * _font)
 {
 	if (_font) painter.setFont(_font);
 	setLabel(_label);
@@ -978,8 +971,8 @@ void Label::draw(float _intensity)
 
 void Label::adjustSize(void)
 {
-	size[0] = (int)ceilf(painter.getFont()->getStrLen(label));
-	size[1] = (int)ceilf(painter.getFont()->getLineHeight());
+	size[0] = (int)std::ceil(painter.getFont()->getStrLen(label));
+	size[1] = (int)std::ceil(painter.getFont()->getLineHeight());
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1082,7 +1075,7 @@ wstring AutoCompleteString::getFirstOption(void)
 
 // we need to set this when actrivated, and only blink the active one
 
-EditBox::EditBox(const wstring& _label, s_font* font) 
+EditBox::EditBox(const wstring& _label, SFont* font) 
 	: Button(), label(_label, font), isEditing(false), cursorPos(0),
 	cursorVisible(false), blinkTimerValid(false)
 {
@@ -1097,15 +1090,15 @@ EditBox::EditBox(const wstring& _label, s_font* font)
 EditBox::~EditBox()
 {
 	if (blinkTimerValid) {
-		SDL_RemoveTimer(blinkTimer);
+		//SDL_RemoveTimer(blinkTimer);
 		blinkTimerValid = false;
 	}
 }
 
-bool EditBox::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool EditBox::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
-	if (state==S_GUI_PRESSED && bt==S_GUI_MOUSE_LEFT)
+	if (state==Stel_MOUSEBUTTONDOWN && bt==Stel_BUTTON_LEFT)
 	{
 		if (isIn(x, y)) 
         {
@@ -1118,7 +1111,7 @@ bool EditBox::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
             return false;
          }
 	}
-	return Button::onClic(x,y,bt,state);
+	return Button::onClic(x,y,bt,state, mod);
 }
 
 void EditBox::setColorScheme(const s_color& baseColor, const s_color& textColor)
@@ -1206,7 +1199,7 @@ void EditBox::setEditing(bool _editing)
 		activeEditBox = this;
 
 		if (!blinkTimerValid) {
-			blinkTimer = SDL_AddTimer(600, toggleBlink, &cursorVisible);
+			//blinkTimer = SDL_AddTimer(600, toggleBlink, &cursorVisible);
 			blinkTimerValid = true;
 		}
 	}
@@ -1216,17 +1209,14 @@ void EditBox::setEditing(bool _editing)
 		cursorVisible = false;
 		autoComplete.reset();
 		activeEditBox = NULL;
-		SDL_RemoveTimer(blinkTimer);
+		//SDL_RemoveTimer(blinkTimer);
 		blinkTimerValid = false;
 	}
 }
 
 void EditBox::setPrompt(const wstring &p)
 {
-	if (p.empty()) 
-		prompt = EDITBOX_DEFAULT_PROMPT; 
-	else 
-		prompt = p; 
+	prompt = p; 
 }
 
 wstring EditBox::getDefaultPrompt(void)
@@ -1234,17 +1224,17 @@ wstring EditBox::getDefaultPrompt(void)
 	return EDITBOX_DEFAULT_PROMPT;
 }
 
-#define SDLK_A 65
-#define SDLK_Z 90
+#define StelKey_A_LIM 65
+#define StelKey_Z_LIM 90
 
-bool EditBox::onKey(Uint16 k, S_GUI_VALUE s)
+bool EditBox::onKey(Uint16 k, Uint8 s, StelMod mod)
 {
     if (!isEditing) return false;
 
-	if (s==S_GUI_PRESSED)
+	if (s==Stel_KEYDOWN)
     { 
 		lastKey = k;
-        if  (k==SDLK_RETURN)
+        if  (k==StelKey_RETURN)
         {
 			if (autoComplete.hasOption()) text = autoComplete.getFirstOption();
             history.add(text);
@@ -1252,42 +1242,42 @@ bool EditBox::onKey(Uint16 k, S_GUI_VALUE s)
             return 1;
         }
 
-  		if (k == SDLK_TAB)
+  		if (k == StelKey_TAB)
   		{
 			if (autoComplete.hasOption()) text = autoComplete.getFirstOption();
 		}
-  		else if (k == SDLK_UP)
+  		else if (k == StelKey_UP)
   		{
               text = history.prev();
               cursorPos = text.length();
         }
-  		else if (k == SDLK_DOWN)
+  		else if (k == StelKey_DOWN)
   		{
               text = history.next();
               cursorPos = text.length();
         }
-  		else if (k == SDLK_LEFT)  		
+  		else if (k == StelKey_LEFT)  		
   		{
-            if (SDL_GetModState() & KMOD_CTRL)
+            if (mod & StelMod_CTRL)
                 cursorToPrevWord();
             else
                 if (cursorPos > 0) cursorPos--;
         }
-        else if (k == SDLK_RIGHT)
+        else if (k == StelKey_RIGHT)
         {
-            if (SDL_GetModState() & KMOD_CTRL)
+            if (mod & StelMod_CTRL)
                 cursorToNextWord();
             else
               if (cursorPos < text.length()) cursorPos++;
         }
-        else if (k == SDLK_HOME) cursorPos = 0;
-        else if (k == SDLK_END)  cursorPos = text.length();
-  		else if (k == SDLK_DELETE)
+        else if (k == StelKey_HOME) cursorPos = 0;
+        else if (k == StelKey_END)  cursorPos = text.length();
+  		else if (k == StelKey_DELETE)
   		{
            text = lastText;
            if (cursorPos < text.length()) text = text.erase(cursorPos, 1);
         }
-        else if (k == SDLK_BACKSPACE)
+        else if (k == StelKey_BACKSPACE)
         {
            text = lastText;
            if (cursorPos > 0)
@@ -1296,10 +1286,16 @@ bool EditBox::onKey(Uint16 k, S_GUI_VALUE s)
                text = text.erase(cursorPos, 1);
            }
         }
-        else if (k == SDLK_ESCAPE) setText(L"");
-        else if ((k >= SDLK_0 && k <= SDLK_9) || (k >= SDLK_a && k <= SDLK_z) 
-        || (k >= SDLK_A && k <= SDLK_Z) || (k >= 224 && k <= 255) 
-		|| k == SDLK_SPACE || k == SDLK_UNDERSCORE)
+        else if (k == StelKey_ESCAPE) setText(L"");
+	else if ((k >= StelKey_0 && k <= StelKey_9)
+		|| (k >= StelKey_a && k <= StelKey_z )
+		|| (k >= StelKey_A_LIM && k <= StelKey_Z_LIM) 
+		|| (k >= StelKey_EXCLAIM && k <= StelKey_SLASH)
+		|| (k >= StelKey_COLON && k <= StelKey_AT)
+		|| (k >= StelKey_LEFTBRACKET && k <= StelKey_BACKQUOTE)
+		|| (k >= 224 && k <= 255)
+		||  k == StelKey_SPACE
+		||  k == StelKey_UNDERSCORE)
         {
 			text = lastText;
             wstring newtext = text.substr(0, cursorPos);
@@ -1393,15 +1389,15 @@ void ScrollBar::draw(void)
 	glPopMatrix();
 }
 
-bool ScrollBar::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool ScrollBar::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
-	if (bt==S_GUI_MOUSE_LEFT && state==S_GUI_RELEASED)
+	if (bt==Stel_MOUSEBUTTONUP && state==Stel_MOUSEBUTTONUP)
 	{
 		dragging = false;
 		return false;
 	}
 	
-	if (visible && isIn(x,y) && state==S_GUI_PRESSED)
+	if (visible && isIn(x,y) && state==Stel_MOUSEBUTTONDOWN)
 	{
 		if (scrollBt.isIn(x-pos[0],y-pos[1])) 
 		{
@@ -1427,13 +1423,13 @@ bool ScrollBar::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
 	return false;
 }
 
-bool ScrollBar::onMove(int x, int y)
+bool ScrollBar::onMove(int x, int y, StelMod mod)
 {
 	float delta, v;
 	
 	if (!visible) return false;
 
-	scrollBt.onMove(x-pos[0],y-pos[1]);
+	scrollBt.onMove(x-pos[0],y-pos[1], mod);
 
 	if (!isIn(x, y)) 
 	{
@@ -1562,7 +1558,7 @@ void ListBox::createLines(void)
 	{
 		bt = new LabeledButton(wstring()); 
 		bt->setHideBorder(true);
-		bt->setHideBorderMouseOver(true);
+		bt->setHideBorderMouseOver(false);
 		bt->setHideTexture(true);
 		bt->setJustification(JUSTIFY_LEFT);
 		bt->adjustSize();
@@ -1596,7 +1592,7 @@ void ListBox::draw(void)
 		else
 		{
 			itemBt[j]->setHideBorder(true);
-			itemBt[j]->setHideBorderMouseOver(true);
+			itemBt[j]->setHideBorderMouseOver(false);
 		}
 		itemBt[j++]->draw();
 		i++;
@@ -1620,7 +1616,7 @@ void ListBox::setCurrent(const wstring& ws)
 	}
 }
 
-bool ListBox::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
+bool ListBox::onClic(int x, int y, Uint8 button, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 	if (!isIn(x,y)) return false;
@@ -1629,16 +1625,16 @@ bool ListBox::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 	y = y - pos[1];
 	if (scrollBar.getVisible())
 	{
-		if (scrollBar.onClic(x, y, button, state)) return true;
+		if (scrollBar.onClic(x, y, button, state, mod)) return true;
 	}
 
-	if (state==S_GUI_PRESSED)
+	if (state==Stel_MOUSEBUTTONDOWN)
 	{
 		int i = firstItemIndex;
     	vector<LabeledButton*>::iterator iter = itemBt.begin();
 		while (iter != itemBt.end())
 		{
-			if ((*iter)->onClic(x, y, button, state)) 
+			if ((*iter)->onClic(x, y, button, state, mod)) 
 			{
 				value = i;
 				if (!onChangeCallback.empty()) RUNCALLBACK(onChangeCallback);
@@ -1652,7 +1648,7 @@ bool ListBox::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 	return false;
 }
 
-bool ListBox::onMove(int x, int y)
+bool ListBox::onMove(int x, int y, StelMod mod)
 {
 	if (!visible) return false;
 	x = x - pos[0];
@@ -1661,10 +1657,10 @@ bool ListBox::onMove(int x, int y)
 	// highlight the item with the mouse over
 	while (iter != itemBt.end())
 	{
-		(*iter)->onMove(x, y); 
+		(*iter)->onMove(x, y, mod); 
    	    iter++;
 	}
-	if (scrollBar.onMove(x, y)) return true;
+	if (scrollBar.onMove(x, y, mod)) return true;
 	
 	return false;
 }
@@ -1760,7 +1756,7 @@ wstring ListBox::getItem(int value)
 
 #define LABEL_PAD 10
 
-LabeledButton::LabeledButton(const wstring& _label, s_font* font, Justification _j, bool _bright) 
+LabeledButton::LabeledButton(const wstring& _label, SFont* font, Justification _j, bool _bright) 
 	: Button(), label(_label, font), justification(_j), isBright(_bright)
 {
 	Component::setSize(label.getSize()+s_vec2i(14,12+(int)label.getFont()->getDescent()));
@@ -1824,7 +1820,7 @@ void LabeledButton::setVisible(bool _visible)
 // A text bloc
 ////////////////////////////////////////////////////////////////////////////////
 
-TextLabel::TextLabel(const wstring& _label, s_font* _font) :
+TextLabel::TextLabel(const wstring& _label, SFont* _font) :
 	Container()
 {
 	if (_font) painter.setFont(_font);
@@ -1846,6 +1842,13 @@ void TextLabel::setLabel(const wstring& _label)
 		label.replace(pos, 2, L"\n");
 	}
 	
+    list<Component*>::iterator iter = childs.begin();
+    while (iter != childs.end())
+    {
+        delete (*iter);
+        (*iter)=NULL;
+        iter++;
+    }
     childs.clear();
 
     Label * tempLabel;
@@ -1962,9 +1965,9 @@ void FramedContainer::setFrameSize(int left, int right, int bottom, int top)
 // Standard window widget
 ////////////////////////////////////////////////////////////////////////////////
 
-StdWin::StdWin(const wstring& _title, const s_texture* _header_tex,
-               s_font * _winfont, int headerSize) :
-	FramedContainer(), titleLabel(NULL), header_tex(NULL), dragging(false)
+StdWin::StdWin(const wstring& _title, const STextureSP _header_tex,
+               SFont * _winfont, int headerSize) :
+	FramedContainer(), titleLabel(NULL), dragging(false)
 {
 	if (_header_tex) header_tex = _header_tex;
 	if (_winfont) painter.setFont(_winfont);
@@ -1991,17 +1994,17 @@ void StdWin::draw()
 	FramedContainer::draw();
 }
 
-bool StdWin::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool StdWin::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
-	if (FramedContainer::onClic(x, y, bt, state)) return 1;
-	if (state==S_GUI_RELEASED && bt==S_GUI_MOUSE_LEFT)
+	if (FramedContainer::onClic(x, y, bt, state, mod)) return 1;
+	if (state==Stel_MOUSEBUTTONUP && bt==Stel_BUTTON_LEFT)
 	{
 		dragging = false;
 	}
 	if (isIn(x, y))
 	{
-		if (state==S_GUI_PRESSED && bt==S_GUI_MOUSE_LEFT)
+		if (state==Stel_MOUSEBUTTONDOWN && bt==Stel_BUTTON_LEFT)
 		{
 			dragging = true;
 			oldPos.set(x,y);
@@ -2011,10 +2014,10 @@ bool StdWin::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
 	return false;
 }
 
-bool StdWin::onMove(int x, int y)
+bool StdWin::onMove(int x, int y, StelMod mod)
 {
 	if (!visible) return false;
-	if (FramedContainer::onMove(x, y)) return 1;
+	if (FramedContainer::onMove(x, y, mod)) return 1;
 	if (dragging)
 	{
 		pos+=(s_vec2i(x,y)-oldPos);
@@ -2035,8 +2038,8 @@ void StdWin::setVisible(bool _visible)
 // Standard Button Window - StdWin with a close button in the title bar
 ////////////////////////////////////////////////////////////////////////////////
 
-StdBtWin::StdBtWin(const wstring& _title, const s_texture* _header_tex,
-                   s_font * _winfont, int headerSize) :
+StdBtWin::StdBtWin(const wstring& _title, const STextureSP _header_tex,
+                   SFont * _winfont, int headerSize) :
 	StdWin(_title, _header_tex, _winfont, headerSize), hideBt(NULL)
 {
 	hideBt = new Button();
@@ -2061,7 +2064,7 @@ void StdBtWin::onHideBt(void)
 
 
 StdTransBtWin::StdTransBtWin(const wstring& _title, int _time_out,
-                             const s_texture* _header_tex, s_font * _winfont,
+                             const STextureSP _header_tex, SFont * _winfont,
                              int headerSize) :
 	StdBtWin(_title, _header_tex, _winfont, headerSize)
 {
@@ -2110,8 +2113,8 @@ void StdTransBtWin::set_timeout(int _time_out)
 #define STDDLGWIN_BT_ICON_LEFT 20
 #define STDDLGWIN_BT_ICON_TOP 20
 
-StdDlgWin::StdDlgWin(const wstring& _title, const s_texture* _header_tex,
-                     s_font * _winfont, int headerSize) :
+StdDlgWin::StdDlgWin(const wstring& _title, STextureSP blankIconTex, STextureSP questionIconTex, STextureSP alertIconTex, const STextureSP _header_tex,
+                     SFont * _winfont, int headerSize) :
 	StdWin(_title, _header_tex, _winfont, headerSize), firstBt(NULL), secondBt(NULL), messageLabel(NULL), 
 	inputEdit(NULL), hasIcon(false)
 {
@@ -2129,9 +2132,9 @@ StdDlgWin::StdDlgWin(const wstring& _title, const s_texture* _header_tex,
 	secondBt->setOnPressCallback(callback<void>(this, &StdDlgWin::onSecondBt));
 	addComponent(secondBt);
 
-	blankIcon = new s_texture("bt_blank.png");
-	questionIcon = new s_texture("bt_question.png");
-	alertIcon = new s_texture("bt_alert.png");
+	blankIcon = blankIconTex;
+	questionIcon = questionIconTex;
+	alertIcon = alertIconTex;
 	picture = new Picture(questionIcon, STDDLGWIN_BT_ICON_LEFT, STDDLGWIN_BT_ICON_TOP, 32, 32);
 	addComponent(picture);
 
@@ -2155,8 +2158,6 @@ StdDlgWin::StdDlgWin(const wstring& _title, const s_texture* _header_tex,
 
 StdDlgWin::~StdDlgWin()
 {
-	delete blankIcon;
-	delete alertIcon;
 }
 
 void StdDlgWin::resetResponse(void)
@@ -2300,7 +2301,7 @@ void StdDlgWin::onSecondBt(void)
 // Everything to handle tabs
 ////////////////////////////////////////////////////////////////////////////////
 
-TabHeader::TabHeader(Component* c, const wstring& _label, s_font* _font) :
+TabHeader::TabHeader(Component* c, const wstring& _label, SFont* _font) :
 	LabeledButton(_label, _font), assoc(c), active(false)
 {
 }
@@ -2336,7 +2337,7 @@ void TabHeader::setActive(bool s)
 	assoc->setVisible(active);
 }
 
-TabContainer::TabContainer(s_font* _font) : Container(), headerHeight(22)
+TabContainer::TabContainer(SFont* _font) : Container(), headerHeight(22)
 {
 	if (_font) painter.setFont(_font);
 }
@@ -2393,13 +2394,13 @@ int TabContainer::getHeadersSize(void)
 	return s;
 }
 
-bool TabContainer::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
+bool TabContainer::onClic(int x, int y, Uint8 button, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 	list<TabHeader*>::iterator iter = headers.begin();
 	while (iter != headers.end())
 	{
-		if ((*iter)->onClic(x - pos[0], y - pos[1], button, state))
+		if ((*iter)->onClic(x - pos[0], y - pos[1], button, state, mod))
 		{
 			select(*iter);
 			(*iter)->setInFront(true);
@@ -2407,7 +2408,7 @@ bool TabContainer::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 		}
         iter++;
     }
-	return Container::onClic(x, y, button, state);
+	return Container::onClic(x, y, button, state, mod);
 }
 
 void TabContainer::select(TabHeader* t)
@@ -2508,15 +2509,15 @@ void CursorBar::setValue(float _value)
 	sized = false;
 }
 
-bool CursorBar::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
+bool CursorBar::onClic(int x, int y, Uint8 bt, Uint8 state, StelMod mod)
 {
-	if (bt==S_GUI_MOUSE_LEFT && state==S_GUI_RELEASED)
+	if (bt==Stel_BUTTON_LEFT && state==Stel_MOUSEBUTTONUP)
 	{
 		dragging = false;
 		return false;
 	}
 	
-	if (visible && isIn(x,y) && state==S_GUI_PRESSED)
+	if (visible && isIn(x,y) && state==Stel_MOUSEBUTTONDOWN)
 	{
 		if (cursorBt.isIn(x-pos[0],y-pos[1])) 
 		{
@@ -2529,13 +2530,13 @@ bool CursorBar::onClic(int x, int y, S_GUI_VALUE bt, S_GUI_VALUE state)
 	return false;
 }
 
-bool CursorBar::onMove(int x, int y)
+bool CursorBar::onMove(int x, int y, StelMod mod)
 {
 	float delta, v;
 	
 	if (!visible) return false;
 	
-	cursorBt.onMove(x-pos[0],y-pos[1]);
+	cursorBt.onMove(x-pos[0],y-pos[1], mod);
 	
 	if (!isIn(x, y)) 
 	{
@@ -2565,8 +2566,8 @@ bool CursorBar::onMove(int x, int y)
 // 
 ////////////////////////////////////////////////////////////////////////////////
 
-IntIncDec::IntIncDec(s_font* _font, const s_texture* tex_up,
-		const s_texture* tex_down, int _min, int _max,
+IntIncDec::IntIncDec(SFont* _font, const STextureSP tex_up,
+		const STextureSP tex_down, int _min, int _max,
 		int _init_value, int _inc, bool _loop) :
 	Container(), value(_init_value), min(_min), max(_max), inc(_inc), btmore(NULL), btless(NULL), label(NULL), loop(_loop)
 {
@@ -2597,7 +2598,7 @@ IntIncDec::~IntIncDec()
 void IntIncDec::draw()
 {
 	if (!visible) return;
-	label->setLabel(StelUtility::doubleToWstring(value));
+	label->setLabel(StelUtils::doubleToWstring(value));
 	Container::draw();
 }
 
@@ -2623,8 +2624,8 @@ void IntIncDec::dec_value()
 	if (!onPressCallback.empty()) onPressCallback();
 }
 		
-IntIncDecVert::IntIncDecVert(s_font* _font, const s_texture* tex_up,
-		const s_texture* tex_down, int _min, int _max,
+IntIncDecVert::IntIncDecVert(SFont* _font, const STextureSP tex_up,
+		const STextureSP tex_down, int _min, int _max,
 		int _init_value, int _inc, bool _loop) : IntIncDec(_font, tex_up, tex_down, _min, _max, _init_value, _inc, loop)
 {
 	label->setPos(0,3);
@@ -2633,8 +2634,8 @@ IntIncDecVert::IntIncDecVert(s_font* _font, const s_texture* tex_up,
 	setSize(_max/10 * 8 + 16,40);
 }
 
-FloatIncDec::FloatIncDec(s_font* _font, const s_texture* tex_up,
-		const s_texture* tex_down, float _min, float _max,
+FloatIncDec::FloatIncDec(SFont* _font, const STextureSP tex_up,
+		const STextureSP tex_down, float _min, float _max,
 		float _init_value, float _inc) :
 	Container(), value(_init_value), min(_min), max(_max), inc(_inc), btmore(NULL), 
 	btless(NULL), label(NULL), format(FORMAT_DEFAULT)
@@ -2669,11 +2670,11 @@ void FloatIncDec::draw()
 	
 	if (format == FORMAT_DEFAULT)
 	{
-		label->setLabel(StelUtility::doubleToWstring(value));
+		label->setLabel(StelUtils::doubleToWstring(value));
 	}
 	else if (format == FORMAT_LONGITUDE || format == FORMAT_LATITUDE)
 	{
-		wstring l = StelUtility::printAngleDMS(value*M_PI/180.);
+		wstring l = StelUtils::radToDmsWstr(value*M_PI/180.);
 		wstring m = l.substr(1);
 		if (format == FORMAT_LATITUDE)
 		{
@@ -2711,8 +2712,8 @@ void FloatIncDec::dec_value()
 // Widget used to set time and date.
 ////////////////////////////////////////////////////////////////////////////////
 
-Time_item::Time_item(s_font* _font, const s_texture* tex_up,
-						const s_texture* tex_down, double _JD) :
+Time_item::Time_item(SFont* _font, const STextureSP tex_up,
+						const STextureSP tex_down, double _JD) :
 						d(NULL), m(NULL), y(NULL), h(NULL), mn(NULL), s(NULL)
 {
 	if (_font) setFont(_font);
@@ -2869,9 +2870,9 @@ void Time_item::onTimeChange(void)
 // 
 ////////////////////////////////////////////////////////////////////////////////
 
-Picture::Picture(const s_texture * _imageTex,
+Picture::Picture(const STextureSP _imageTex,
                  int xpos, int ypos, int xsize, int ysize) :
-	imageTex(_imageTex), imgcolor(s_color(1,1,1))
+	imageTex(_imageTex), imgcolor(s_color(s_vec3(1,1,1)))
 {
 	setPos(xpos, ypos);
 	setSize(xsize, ysize);
@@ -2881,8 +2882,6 @@ Picture::Picture(const s_texture * _imageTex,
 
 Picture::~Picture()
 {
-	if (imageTex) delete imageTex;
-	imageTex = NULL;
 }
 
 void Picture::draw(void)
@@ -2893,6 +2892,11 @@ void Picture::draw(void)
 	if (showedges) painter.drawSquareEdge(pos, size);
 }
 
+void Picture::setPictureTexture(const STextureSP _imageTex)
+{
+	imageTex = _imageTex;
+	painter.setTexture(imageTex);
+}
 
 ///////////////////////////// MapPicture  //////////////////////////////////////
 // MapPicture - for selecting the current location
@@ -2910,11 +2914,7 @@ City_Mgr::City_Mgr(double _proximity) : proximity(_proximity)
 
 City_Mgr::~City_Mgr()
 {
-	vector<City*>::iterator iter;
-	for (iter = cities.begin();iter!=cities.end();iter++)
-	{
-		delete (*iter);
-	}
+	clearCities();
 }
 
 void City_Mgr::addCity(const string& _name, const string& _state, 
@@ -2924,6 +2924,16 @@ void City_Mgr::addCity(const string& _name, const string& _state,
 	cities.push_back(city);
 }
 
+void City_Mgr::clearCities(void)
+{
+	vector<City*>::iterator iter;
+	for (iter = cities.begin();iter!=cities.end();iter++)
+	{
+		delete (*iter);
+	}
+	cities.clear();
+}
+
 int City_Mgr::getNearest(double _longitude, double _latitude)
 {
 	double dist, closest=10000.;
@@ -2937,9 +2947,9 @@ int City_Mgr::getNearest(double _longitude, double _latitude)
     while (i < (int)cities.size())
     {
 		name = cities[i]->getName();
-		dist = powf(_latitude - cities[i]->getLatitude(),2.f) +
-			powf(_longitude - cities[i]->getLongitude(),2.f);
-		dist = powf(dist,0.5f);
+		dist = std::pow(_latitude - cities[i]->getLatitude(),2.) +
+			std::pow(_longitude - cities[i]->getLongitude(),2.);
+		dist = std::pow(dist,0.5);
 		if (index == -1) 
 		{
 			closest = dist;
@@ -2980,14 +2990,14 @@ void City_Mgr::setProximity(double _proximity)
 ////////////////////////////////////////////////////////////////////////////////
 #define POINTER_SIZE 10
 #define CITY_SIZE 5
-#define CITY_SELECT s_color(1,0,0)
-#define CITY_HOVER s_color(1,1,0)
-#define CITY_WITH_NAME s_color(1,.4,0)
-#define CITY_WITHOUT_NAME s_color(.8,.6,0)
+#define CITY_SELECT s_color(s_vec3(1,0,0))
+#define CITY_HOVER s_color(s_vec3(1,1,0))
+#define CITY_WITH_NAME s_color(s_vec3(1,.4,0))
+#define CITY_WITHOUT_NAME s_color(s_vec3(.8,.6,0))
 
-MapPicture::MapPicture(const s_texture *_imageTex,
-                       const s_texture *_pointerTex,
-                       const s_texture *_cityTex,
+MapPicture::MapPicture(const STextureSP _imageTex,
+                       const STextureSP _pointerTex,
+                       const STextureSP _cityTex,
                        int xpos, int ypos, int xsize, int ysize) :
 	Picture(_imageTex, xpos, ypos, xsize, ysize), pointer(NULL), panning(false), 
 	dragging(false), zoom(1.f), sized(false), exact(false)
@@ -3009,23 +3019,10 @@ MapPicture::~MapPicture()
 {
 	delete pointer;
 	pointer = NULL;
-
-	if (city_name_font) delete city_name_font;
-	city_name_font = NULL;
 	
 	delete cityPointer;
 }
 
-void MapPicture::set_font(float font_size, const string& font_name)
-{
-	city_name_font = new s_font(font_size, font_name);
-	if (!city_name_font)
-	{
-		printf("Can't create city_name_font\n");
-		exit(-1);
-	}
-	fontsize = font_size;
-}
 
 #define CITY_TYPE_NAMED 1
 #define CITY_TYPE_UNNAMED 2
@@ -3056,7 +3053,7 @@ void MapPicture::drawCityName(const s_vec2i& cityPos, const wstring& _name)
 	if ((cityPos[0] > originalPos[0] + originalSize[0]) || (cityPos[0] < originalPos[0]))
 		return;
 		
-	y = cityPos[1]-(int)(fontsize/2);
+	y = cityPos[1]-(int)(city_name_font->getLineHeight()/2);
 	strLen = (int)city_name_font->getStrLen(_name);
 	x = cityPos[0] + cityPointer->getSizex()/2 + 1;
 	if (x + strLen + 1 >= originalPos[0] + originalSize[0])
@@ -3130,18 +3127,17 @@ void MapPicture::draw(void)
 		sized = true;
 	}
 	
-    glPushMatrix();
-    Component::scissor->push(originalPos, originalSize);
+	glPushMatrix();
+	Component::scissor->push(originalPos, originalSize);
 
 	Picture::draw();
 
 	drawCities();
 	drawNearestCity();
-	
-	if (zoom == 1) 
-		pointer->setSize((int)zoom*6, (int)zoom*6);
-	else
-		pointer->setSize((int)(zoom*2), (int)(zoom*2));
+	float pointerScale = 20;
+	if (zoom > 4) pointerScale *= (zoom - 2.5)/2;
+	pointer->setSize((int)pointerScale, (int)pointerScale);
+		
 	pointer->setPos(s_vec2i(pointerPos[0]+pos[0]-pointer->getSizex()/2, pointerPos[1]+pos[1]-pointer->getSizey()/2));
 	pointer->draw();
 	
@@ -3156,13 +3152,13 @@ bool MapPicture::isIn(int x, int y)
 	return (originalPos[0]<=x && (originalSize[0]+originalPos[0])>=x && originalPos[1]<=y && (originalPos[1]+originalSize[1])>=y);
 }
 
-bool MapPicture::onKey(Uint16 k, S_GUI_VALUE s)
+bool MapPicture::onKey(Uint16 k, Uint8 s, StelMod mod)
 {
-	if (s==S_GUI_PRESSED)
+	if (s==Stel_KEYDOWN)
 	{
-		if (k == SDLK_PAGEUP) 
+		if (k == StelKey_PAGEUP) 
 			zoomInOut(1.f);
-		else if (k == SDLK_PAGEDOWN) 
+		else if (k == StelKey_PAGEDOWN) 
 			zoomInOut(-1.f);
 		else
 			return false;
@@ -3171,9 +3167,9 @@ bool MapPicture::onKey(Uint16 k, S_GUI_VALUE s)
 	return false;
 }
 
-void MapPicture::calcPointerPos(int x, int y)
+void MapPicture::calcPointerPos(int x, int y, StelMod mod)
 {
-	if (SDL_GetModState() & KMOD_CTRL)
+	if (mod & StelMod_CTRL)
 	{
 		nearestIndex = cities.getNearest(getLongitudeFromx(x - pos[0]), getLatitudeFromy(y - pos[1]));
 		if (nearestIndex != -1)
@@ -3202,7 +3198,7 @@ void MapPicture::calcPointerPos(int x, int y)
 	exact = false;
 }
 
-bool MapPicture::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
+bool MapPicture::onClic(int x, int y, Uint8 button, Uint8 state, StelMod mod)
 {
 	if (!visible) return false;
 
@@ -3213,20 +3209,20 @@ bool MapPicture::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 		return false;
 	}
 
-	if (button==S_GUI_MOUSE_LEFT)
+	if (button==Stel_BUTTON_LEFT)
 	{
-		if (state == S_GUI_PRESSED)
+		if (state == Stel_MOUSEBUTTONDOWN)
 		{
 			dragging = true;
-			calcPointerPos(x, y);
+			calcPointerPos(x, y, mod);
 			if (!onPressCallback.empty()) RUNCALLBACK(onPressCallback);
 		}
 		else
 			dragging = false;
 	}
-	if (button==S_GUI_MOUSE_RIGHT)
+	if (button==Stel_BUTTON_RIGHT)
 	{
-		if (state == S_GUI_PRESSED)
+		if (state == Stel_MOUSEBUTTONDOWN)
 		{
 			panning = true;
 			oldPos.set(x,y);
@@ -3234,14 +3230,14 @@ bool MapPicture::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
 		else
 			panning = false;
 	}
-	else if (button == 	S_GUI_MOUSE_WHEELUP)
+	else if (button == 	Stel_BUTTON_WHEELUP)
 		zoomInOut(0.5f); //polls twice - press and release I assume
-	else if (button == 	S_GUI_MOUSE_WHEELDOWN)
+	else if (button == 	Stel_BUTTON_WHEELDOWN)
 		zoomInOut(-0.5f);
 	return true;
 }
 
-bool MapPicture::onMove(int x, int y)
+bool MapPicture::onMove(int x, int y, StelMod mod)
 {
 	if (!visible) return false;
  	if (!isIn(x,y)) return false;
@@ -3251,7 +3247,7 @@ bool MapPicture::onMove(int x, int y)
 
 	if (dragging)
 	{
-		calcPointerPos(x, y);
+		calcPointerPos(x, y, mod);
 		if (!onPressCallback.empty()) RUNCALLBACK(onPressCallback);
 	}
 	else if (panning)
@@ -3438,9 +3434,9 @@ void StringList::draw(void)
 	}
 }
 
-bool StringList::onClic(int x, int y, S_GUI_VALUE button, S_GUI_VALUE state)
+bool StringList::onClic(int x, int y, Uint8 button, Uint8 state, StelMod mod)
 {
-	if (!visible || state!=S_GUI_PRESSED || !isIn(x,y)) return 0;
+	if (!visible || state!=Stel_MOUSEBUTTONDOWN || !isIn(x,y)) return 0;
 	int poss = (y-pos[1])/itemSize;
 	if (items.begin()+poss == items.end() || (unsigned int)poss>items.size()) return 1;
 	current = items.begin()+poss;
