@@ -17,8 +17,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-// TODO : remove the maximum of char* and replace by string to make the soft safer
-
 #ifndef _GUI_H_
 #define _GUI_H_
 
@@ -26,25 +24,24 @@
 # include <config.h>
 #endif
 
-#include "SDL_opengl.h"
-
-// SDL is used only for the key codes, i'm lasy to redefine them
-// This is TODO to make the s_ library independent
-#include "SDL.h"
+#include "GLee.h"
+#include "StelKey.hpp"
+#include "StelTypes.hpp"
 
 #include <list>
 #include <string>
+#include <sstream>
 #include <vector>
 #include <map>
 
-#include "s_texture.h"
-#include "s_font.h"
+#include "STextureTypes.hpp"
+#include "SFont.hpp"
 #include "vecmath.h"
 #include "callbacks.hpp"
 
-#include "translator.h"
+#include "Translator.hpp"
 
-void glCircle(const Vec3d& pos, float radius, float linewidth = 1.0);
+void glCircleGui(const Vec3d& pos, float radius, float linewidth = 1.0);
 void glEllipse(const Vec3d& pos, float radius, float y_ratio, float linewidth = 1.0);
 
 using namespace std;
@@ -96,24 +93,13 @@ void* getLastCallbackObject(void);
 
 namespace s_gui
 {
-	// gui Return Values:
-	enum S_GUI_VALUE
-	{
-		S_GUI_MOUSE_LEFT,
-		S_GUI_MOUSE_RIGHT,
-    	S_GUI_MOUSE_MIDDLE,
-		S_GUI_MOUSE_WHEELUP,
-		S_GUI_MOUSE_WHEELDOWN,
-		S_GUI_PRESSED,
-		S_GUI_RELEASED
-	};
-
 	typedef Vec4f s_color;
+	typedef Vec3f s_vec3;
 	typedef Vec4i s_square;
 	typedef Vec2i s_vec2i;
 	typedef Vec4i s_vec4i;
 
-	static const s_color s_white = s_color(1,1,1);
+	static const s_color s_white = s_color(s_vec3(1,1,1));
 
 	class Scissor
 	{
@@ -134,12 +120,12 @@ namespace s_gui
     public:
         Painter();
 		~Painter();
-		Painter(const s_texture* _tex1, s_font* _font, const s_color& _baseColor, const s_color& _textColor);
+		Painter(const STextureSP _tex1, SFont* _font, const s_color& _baseColor, const s_color& _textColor);
 		void drawSquareEdge(const s_vec2i& pos, const s_vec2i& sz) const;
 		void drawSquareEdge(const s_vec2i& pos, const s_vec2i& sz, const s_color& c) const;
 		void drawSquareFill(const s_vec2i& pos, const s_vec2i& sz) const;
 		void drawSquareFill(const s_vec2i& pos, const s_vec2i& sz, const s_color& c) const;
-		void drawSquareFill(const s_vec2i& pos, const s_vec2i& sz, const s_color& c, const s_texture * t) const;
+		void drawSquareFill(const s_vec2i& pos, const s_vec2i& sz, const s_color& c, const STextureSP  t) const;
 		void drawCross(const s_vec2i& pos, const s_vec2i& sz) const;
 		void drawLine(const s_vec2i& pos1, const s_vec2i& pos2) const;
 		void drawLine(const s_vec2i& pos1, const s_vec2i& pos2, const s_color& c) const;
@@ -147,17 +133,17 @@ namespace s_gui
 		void print(int x, int y, const string& str, const s_color& c);
 		void print(int x, int y, const wstring& str);
 		void print(int x, int y, const wstring& str, const s_color& c);		
-		void setTexture(const s_texture* tex) {tex1 = tex;}
-		void setFont(s_font* f) {font = f;}
+		void setTexture(const STextureSP tex) {tex1 = tex;}
+		void setFont(SFont* f) {font = f;}
 		void setTextColor(const s_color& c) {textColor = c;}
 		void setBaseColor(const s_color& c) {baseColor = c;}
 		const s_color& getBaseColor(void) const {return baseColor;}
 		const s_color& getTextColor(void) const {return textColor;}
-		s_font* getFont(void) const {return font;}
+		SFont* getFont(void) const {return font;}
 		void setOpaque(bool _b) { opaque = _b; }
     private:
-		const s_texture* tex1;
-		s_font* font;
+		STextureSP tex1;
+		SFont* font;
 		s_color baseColor;
 		s_color textColor;
 		bool opaque;
@@ -200,12 +186,12 @@ namespace s_gui
         virtual int getVisible(void) const {return visible;}
         virtual void setFocus(bool _focus) { focus = _focus; };
         virtual bool getFocus(void) const {return focus;}
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE) {return 0;}
-		virtual bool onMove(int, int) {return 0;}
-		virtual bool onKey(Uint16, S_GUI_VALUE) {return 0;}
-		virtual void setTexture(const s_texture* tex) {painter.setTexture(tex);}
-		virtual void setFont(s_font* f) {painter.setFont(f);}
-		s_font* getFont(void) const {return painter.getFont();}
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod) {return 0;}
+		virtual bool onMove(int, int, StelMod) {return 0;}
+		virtual bool onKey(Uint16, Uint8, StelMod) {return 0;}
+		virtual void setTexture(const STextureSP tex) {painter.setTexture(tex);}
+		virtual void setFont(SFont* f) {painter.setFont(f);}
+		SFont* getFont(void) const {return painter.getFont();}
 		virtual void setTextColor(const s_color& c) {painter.setTextColor(c);}
 		virtual void setBaseColor(const s_color& c) {painter.setBaseColor(c);}
 		virtual void setPainter(const Painter& p) {painter = p;}
@@ -250,8 +236,8 @@ namespace s_gui
 		virtual void setOnMouseInOutCallback(const callback<void>& c) {onMouseInOutCallback = c;}
         virtual void setOnPressCallback(const callback<void>& c) {onPressCallback = c;}
 		virtual bool getIsMouseOver(void) {return is_mouse_over;}
-		virtual bool onMove(int, int);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onMove(int, int, StelMod);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
     protected:
 		callback<void> onPressCallback;
 		callback<void> onMouseInOutCallback;
@@ -269,9 +255,9 @@ namespace s_gui
         virtual void removeComponent(Component*);
 		virtual void removeAllComponents(void);
         virtual void draw(void);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
-		virtual bool onKey(Uint16, S_GUI_VALUE);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
+		virtual bool onMove(int, int, StelMod);
+		virtual bool onKey(Uint16, Uint8, StelMod mod);
         virtual void setFocus(bool _focus);
    		void setGUIColorSchemeMember(bool _b);
 		void setColorScheme(const s_color& _baseColor, const s_color& _textColor);
@@ -298,7 +284,7 @@ namespace s_gui
     public:
 		Button();
         virtual void draw();
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
 		void setHideBorder(bool _b) { hideBorder = _b;}
 		void setHideBorderMouseOver(bool _b) { hideBorderMouseOver = _b;}
 		void setHideTexture(bool _b) { hideTexture = _b;}
@@ -315,7 +301,7 @@ namespace s_gui
     class TexturedButton : public Button
     {
     public:
-		TexturedButton(const s_texture* tex = NULL);
+		TexturedButton(const STextureSP tex = STextureSP());
         virtual void draw();
     protected:
     };
@@ -338,7 +324,7 @@ namespace s_gui
         virtual void draw();
 		virtual int getState(void) const {return isChecked;}
 		virtual void setState(bool s) {isChecked = s;}
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
     protected:
 		bool isChecked;
     };
@@ -346,11 +332,11 @@ namespace s_gui
 	class FlagButton : public CheckBox
     {
     public:
-		FlagButton(int state = 0, const s_texture* tex = NULL, const string& specificTexName = "");
+		FlagButton(int state = 0, const STextureSP tex=STextureSP(), STextureSP specificTex=STextureSP());
         virtual ~FlagButton();
 		virtual void draw();
     protected:
-		const s_texture* specific_tex;
+		STextureSP specific_tex;
     };
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -360,7 +346,7 @@ namespace s_gui
     class Label : public Component
     {
     public:
-        Label(const wstring& _label = L"", s_font* _font = NULL);
+        Label(const wstring& _label = L"", SFont* _font = NULL);
         virtual ~Label();
         virtual const wstring& getLabel() const {return label;}
         /** @brief Set new label */
@@ -382,13 +368,13 @@ namespace s_gui
     {
 		friend class TabContainer;
     public:
-        LabeledButton(const wstring& _label = L"", s_font* font = NULL, 
+        LabeledButton(const wstring& _label = L"", SFont* font = NULL, 
 			Justification _j = JUSTIFY_CENTER, bool _bright = false);
 		virtual ~LabeledButton();
         virtual void draw(void);
 		virtual void setColorScheme(const s_color& baseColor, const s_color& textColor);
 		virtual void setVisible(bool _visible);
-		virtual void setFont(s_font* f) {Button::setFont(f); label.setFont(f);}
+		virtual void setFont(SFont* f) {Button::setFont(f); label.setFont(f);}
 		virtual void setTextColor(const s_color& c) {Button::setTextColor(c); label.setTextColor(c);}
 		virtual void setPainter(const Painter& p) {Button::setPainter(p); label.setPainter(p);}
 		virtual void setJustification(Justification _j) { justification = _j; }
@@ -446,23 +432,24 @@ namespace s_gui
     class EditBox : public Button
     {
     public:
-        EditBox(const wstring& _label = L"", s_font* font = NULL);
+        EditBox(const wstring& _label = L"", SFont* font = NULL);
 		virtual ~EditBox();
 		virtual void setOnReturnKeyCallback(const callback<void>& c) {onReturnKeyCallback = c;}
 		virtual void setOnKeyCallback(const callback<void>& c) {onKeyCallback = c;}
 		virtual void setOnAutoCompleteCallback(const callback<void>& c) {onAutoCompleteCallback = c;}
         virtual void draw(void);
 		virtual void setColorScheme(const s_color& baseColor, const s_color& textColor);
-		virtual void setFont(s_font* f) {Button::setFont(f); label.setFont(f);}
+		virtual void setFont(SFont* f) {Button::setFont(f); label.setFont(f);}
 		virtual void setTextColor(const s_color& c) {Button::setTextColor(c); label.setTextColor(c);}
 		virtual void setPainter(const Painter& p) {Button::setPainter(p); label.setPainter(p);}
-		virtual bool onKey(Uint16, S_GUI_VALUE);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onKey(Uint16, Uint8, StelMod mod);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
 		void setVisible(bool _visible);
 		void setAutoCompleteOptions(vector<wstring> _autocomplete) { autoComplete.setOptions(_autocomplete); };
 		wstring getAutoCompleteOptions(void) { return autoComplete.getOptions(); }
 		wstring getText(void) { return text; }
 		void setEditing(bool _b);
+		bool getEditing() const {return isEditing;}
 		void refreshLabel(void);
 		void setPrompt(const wstring &p);
 		void setPrompt(void) { setPrompt(wstring()); };
@@ -494,7 +481,7 @@ namespace s_gui
 		bool autoFocus;
 		bool cursorVisible;
 		bool blinkTimerValid;
-		SDL_TimerID blinkTimer;
+		//SDL_TimerID blinkTimer;
     };
 	
 	class ScrollBar : public CallbackComponent
@@ -503,8 +490,8 @@ namespace s_gui
 		ScrollBar(bool _vertical = true, int _totalElements = 1, int _elementsForBar = 1);
 		virtual void setOnChangeCallback(const callback<void>& c) {onChangeCallback = c;}
 		virtual void draw(void);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
+		virtual bool onMove(int, int, StelMod);
 		void setTotalElements(int _elements);
 		void setElementsForBar(int _elementsForBar);
 		void setValue(int _value);
@@ -532,8 +519,8 @@ namespace s_gui
 		ListBox(int _displayLines = 5);
 		~ListBox();
 		virtual void setOnChangeCallback(const callback<void>& c) {onChangeCallback = c;}
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
+		virtual bool onMove(int, int, StelMod);
         virtual void draw(void);
    		virtual void setVisible(bool _visible);
 		wstring getItem(int value);
@@ -561,7 +548,7 @@ namespace s_gui
     class TextLabel : public Container
 	{
 	public:
-	    TextLabel(const wstring& _label = L"", s_font* _font = NULL);
+	    TextLabel(const wstring& _label = L"", SFont* _font = NULL);
 	    virtual ~TextLabel();
         virtual const wstring& getLabel() const {return label;}
         virtual void draw(void);
@@ -575,8 +562,13 @@ namespace s_gui
 	class IntIncDec : public Container
 	{
 	public:
-	    IntIncDec(s_font* _font = NULL, const s_texture* tex_up = NULL,
-			const s_texture* tex_down = NULL, int min = 0, int max = 9,
+//	    IntIncDec(SFont* _font = NULL, const STextureSP tex_up = NULL,
+//			const STextureSP tex_down = NULL, int min = 0, int max = 9,
+//			int init_value = 0, int inc = 1, bool _loop = false);
+	    IntIncDec(SFont* _font,
+			const STextureSP tex_up,
+			const STextureSP tex_down,
+			int min = 0, int max = 9,
 			int init_value = 0, int inc = 1, bool _loop = false);
 	    virtual ~IntIncDec();
 		virtual void draw();
@@ -595,8 +587,8 @@ namespace s_gui
 	class IntIncDecVert : public IntIncDec
 	{
 	public:
-	    IntIncDecVert(s_font* _font = NULL, const s_texture* tex_up = NULL,
-			const s_texture* tex_down = NULL, int min = 0, int max = 9,
+	    IntIncDecVert(SFont* _font = NULL, const STextureSP tex_up=STextureSP(),
+			const STextureSP tex_down=STextureSP(), int min = 0, int max = 9,
 			int init_value = 0, int inc = 1, bool _loop = false);
 	};
 
@@ -604,8 +596,8 @@ namespace s_gui
 	class FloatIncDec : public Container
 	{
 	public:
-	    FloatIncDec(s_font* _font = NULL, const s_texture* tex_up = NULL,
-			const s_texture* tex_down = NULL, float min = 0.f, float max = 1.0f,
+	    FloatIncDec(SFont* _font = NULL, const STextureSP tex_up=STextureSP(),
+			const STextureSP tex_down=STextureSP(), float min = 0.f, float max = 1.0f,
 			float init_value = 0.5f, float inc = 0.1f);
 	    virtual ~FloatIncDec();
 		virtual void draw();
@@ -626,8 +618,8 @@ namespace s_gui
     class Time_item : public Container
     {
     public:
-		Time_item(s_font* _font = NULL, const s_texture* tex_up = NULL,
-			const s_texture* tex_down = NULL, double _JD = 2451545.0);
+		Time_item(SFont* _font = NULL, const STextureSP tex_up=STextureSP(),
+			const STextureSP tex_down=STextureSP(), double _JD = 2451545.0);
 		double getJDay(void) const;
 		string getDateString(void);
 		void setJDay(double jd);
@@ -675,17 +667,17 @@ namespace s_gui
 	class StdWin : public FramedContainer
 	{
 	public:
-	    StdWin(const wstring& _title = L"", const s_texture* _header_tex = NULL,
-			s_font * _winfont = NULL, int headerSize = 18);
+	    StdWin(const wstring& _title = L"", const STextureSP _header_tex = STextureSP(),
+			SFont * _winfont = NULL, int headerSize = 18);
 	   	virtual void draw();
 	    virtual wstring getTitle() const {return titleLabel->getLabel();}
 	    virtual void setTitle(const wstring& _title);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
+		virtual bool onMove(int, int, StelMod);
 		virtual void setVisible(bool _visible);
 	protected:
 	    Label* titleLabel;
-		const s_texture* header_tex;
+		STextureSP header_tex;
 		int dragging;
 		s_vec2i oldPos;
 	};
@@ -707,9 +699,9 @@ namespace s_gui
 	class StdDlgWin : public StdWin
 	{
 	public:
-		StdDlgWin(const wstring& _title = NULL,
-                  const s_texture* _header_tex = NULL,
-                  s_font * _winfont = NULL, int headerSize = 18);
+		StdDlgWin(const wstring& _title,  STextureSP blankIconTex, STextureSP questionIconTex, STextureSP alertIconTex,
+                  const STextureSP _header_tex = STextureSP(),
+                  SFont * _winfont = NULL, int headerSize = 18);
 		~StdDlgWin();
 		virtual void setDialogCallback(const callback<void>& c) {onCompleteCallback = c;}
 		void MessageBox(const wstring &_title, const wstring &_prompt, int _buttons, const string &_ID = "");
@@ -729,9 +721,9 @@ namespace s_gui
 		LabeledButton *firstBt, *secondBt;
 		TextLabel *messageLabel;
 		EditBox *inputEdit;
-		const s_texture *blankIcon;
-		const s_texture *questionIcon;
-		const s_texture *alertIcon;
+		STextureSP blankIcon;
+		STextureSP questionIcon;
+		STextureSP alertIcon;
 		Picture *picture;
 		wstring originalTitle;
 		bool hasIcon;
@@ -747,8 +739,8 @@ namespace s_gui
 	{
 	public:
 	    StdBtWin(const wstring& _title = NULL,
-                 const s_texture* _header_tex = NULL,
-			s_font * _winfont = NULL, int headerSize = 18);
+                 const STextureSP _header_tex = STextureSP(),
+			SFont * _winfont = NULL, int headerSize = 18);
 		virtual void draw();
 		virtual void setOnHideBtCallback(const callback<void>& c) {onHideBtCallback = c;}
 	protected:
@@ -762,8 +754,8 @@ namespace s_gui
 	{
 	public:
 	    StdTransBtWin(const wstring& _title = L"", int _time_out =0,
-                      const s_texture* _header_tex = NULL,
-			s_font * _winfont = NULL, int headerSize = 18);
+                      const STextureSP _header_tex = STextureSP(),
+			SFont * _winfont = NULL, int headerSize = 18);
 		virtual void update(int _delta_time);
 		virtual void set_timeout(int _time_out=0);
 	protected:
@@ -774,7 +766,7 @@ namespace s_gui
 	class TabHeader : public LabeledButton
 	{
 	public:
-		TabHeader(Component*, const wstring& _label = L"", s_font* _font = NULL);
+		TabHeader(Component*, const wstring& _label = L"", SFont* _font = NULL);
 		void draw(void);
 		void setActive(bool);
 	protected:
@@ -785,10 +777,10 @@ namespace s_gui
 	class TabContainer : public Container
 	{
 	public:
-		TabContainer(s_font* _font = NULL);
+		TabContainer(SFont* _font = NULL);
 		void addTab(Component* c, const wstring& name);
 		virtual void draw(void);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
 		virtual void setColorScheme(const s_color& baseColor, const s_color& textColor);
 	protected:
 		int getHeadersSize(void);
@@ -806,8 +798,8 @@ namespace s_gui
         virtual float getValue(void) {return value;}
 		virtual void setValue(float _value);
 		virtual void setOnChangeCallback(const callback<void>& c) {onChangeCallback = c;}
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
+		virtual bool onMove(int, int, StelMod);
 	private:
 		void adjustSize(void);
 		bool dragging;
@@ -825,14 +817,15 @@ namespace s_gui
     class Picture : public CallbackComponent
 	{
 	public:
-	    Picture(const s_texture * _imageTex,
+	    Picture(const STextureSP  _imageTex,
                 int xpos = 0, int ypos = 0, int xsize = 32, int ysize = 32);
 		~Picture();
 		virtual void draw(void);
 		void setShowEdge(bool v) {showedges = v;}
 		void setImgColor(const s_color &c) {imgcolor = c;}
+		void setPictureTexture(const STextureSP _imageTex);
 	private:
-	    const s_texture * imageTex;
+		STextureSP imageTex;
 		bool showedges;
 		s_color imgcolor;
 	};
@@ -877,6 +870,7 @@ namespace s_gui
 		void setProximity(double _proximity);
 		City *getCity(unsigned int _index);
 		unsigned int size(void) { return cities.size(); }
+		void clearCities(void);
 	private:
 		vector<City*> cities;
 		double proximity;
@@ -887,20 +881,18 @@ namespace s_gui
     class MapPicture : public Picture
 	{
 	public:
-	    MapPicture(const s_texture *_imageTex,
-                   const s_texture *_pointerTex,
-                   const s_texture *_cityTex,
+	    MapPicture(const STextureSP _imageTex,
+                   const STextureSP _pointerTex,
+                   const STextureSP _cityTex,
                    int xpos = 0, int ypos = 0, int xsize = 32, int ysize = 32);
 		~MapPicture();
 		virtual void setOnNearestCityCallback(const callback<void>& c) {onNearestCityCallback = c;}
 		virtual void draw(void);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
-		virtual bool onMove(int, int);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod mod);
+		virtual bool onMove(int, int, StelMod);
 		virtual bool isIn(int x, int y);
-		bool onKey(Uint16 k, S_GUI_VALUE s);
-
-		void set_font(float font_size, const string& font_name);
-
+		bool onKey(Uint16 k, Uint8 s, StelMod);
+		void set_font(SFont* newFont) {city_name_font = newFont;}
 		double getPointerLongitude(void);
 		double getPointerLatitude(void);
 		int getPointerAltitude(void);
@@ -910,7 +902,9 @@ namespace s_gui
 		void zoomInOut(float _amount);
 		
 		void addCity(const string& _name, const string& _state, const string& _country, 
-			double _longitude, double _latitude, float _zone, int _showatzoom, int _altitude) { cities.addCity(_name, _state, _country, _longitude, _latitude, _zone, _showatzoom, _altitude);}
+			double _longitude, double _latitude, float _zone, int _showatzoom, int _altitude) {cities.addCity(_name, _state, _country, _longitude, _latitude, _zone, _showatzoom, _altitude);}
+		void clearCities(void) {cities.clearCities(); nearestIndex = -1; pointerIndex = -1;}
+		void setMapTexture(const STextureSP _newTex) { setPictureTexture(_newTex); }
 		string getPositionString(void);
 		string getCursorString(void);
 		void findPosition(double longitude, double latitude);
@@ -928,11 +922,11 @@ namespace s_gui
 		void drawCityName(const s_vec2i& cityPos, const wstring& _name);
 		void drawCity(const s_vec2i& cityPos, int ctype);
 		void drawNearestCity(void);
-		void calcPointerPos(int x, int y);
+		void calcPointerPos(int x, int y, StelMod mod);
 		void setPointerSize(void);
 		Picture *pointer;
 		Picture *cityPointer;
-		s_font *city_name_font;
+		SFont* city_name_font;
 		s_vec2i pointerPos, oldPos;
 		s_vec2i originalSize, originalPos;
 		s_vec2i cursorPos;
@@ -945,7 +939,6 @@ namespace s_gui
 		bool exact;
 		double exactLatitude, exactLongitude;
 		int exactAltitude;
-		float fontsize;
 	};
 
     class StringList : public CallbackComponent
@@ -953,7 +946,7 @@ namespace s_gui
 	public:
 		StringList();
 		virtual void draw(void);
-		virtual bool onClic(int, int, S_GUI_VALUE, S_GUI_VALUE);
+		virtual bool onClic(int, int, Uint8, Uint8, StelMod);
 		void addItem(const string &);
 		void addItemList(const string& s)
 		{
