@@ -91,7 +91,7 @@ wstring Container::getString(void)
 }
 
 
-bool Container::onKey(Uint16 k, S_TUI_VALUE s)
+bool Container::onKey(Uint16 k, Uint8 s)
 {
 	list<Component*>::iterator iter = childs.begin();
 	while (iter != childs.end())
@@ -151,22 +151,22 @@ bool Branch::setValue_Specialslash(const wstring& s)
 	return false;
 }
 
-bool Branch::onKey(Uint16 k, S_TUI_VALUE v)
+bool Branch::onKey(Uint16 k, Uint8 v)
 {
 	if (!*current) return false;
-	if (v==S_TUI_RELEASED) return (*current)->onKey(k,v);
-	if (v==S_TUI_PRESSED)
+	if (v==Stel_KEYUP) return (*current)->onKey(k,v);
+	if (v==Stel_KEYDOWN)
 	{
 		if ((*current)->onKey(k,v)) return true;
 		else
 		{
-			if (k==SDLK_UP)
+			if (k==StelKey_UP)
 			{
 				if (current!=childs.begin()) --current;
 				else current=--childs.end();
 				return true;
 			}
-			if (k==SDLK_DOWN)
+			if (k==StelKey_DOWN)
 			{
 				if (current!=--childs.end()) ++current;
 				else current=childs.begin();
@@ -182,14 +182,14 @@ MenuBranch::MenuBranch(const wstring& s) : Branch(), label(s), isNavigating(fals
 {
 }
 
-bool MenuBranch::onKey(Uint16 k, S_TUI_VALUE v)
+bool MenuBranch::onKey(Uint16 k, Uint8 v)
 {
 	if (isNavigating)
 	{
 		if (isEditing)
 		{
 			if ((*Branch::current)->onKey(k, v)) return true;
-			if (v==S_TUI_PRESSED && (k==SDLK_LEFT || k==SDLK_ESCAPE || k==SDLK_RETURN))
+			if (v==Stel_KEYDOWN && (k==StelKey_LEFT || k==StelKey_ESCAPE || k==StelKey_RETURN))
 			{
 				isEditing = false;
 				return true;
@@ -198,22 +198,22 @@ bool MenuBranch::onKey(Uint16 k, S_TUI_VALUE v)
 		}
 		else
 		{
-			if (v==S_TUI_PRESSED && k==SDLK_UP)
+			if (v==Stel_KEYDOWN && k==StelKey_UP)
 			{
 				if (Branch::current!=Branch::childs.begin()) --Branch::current;
 				return true;
 			}
-			if (v==S_TUI_PRESSED && k==SDLK_DOWN)
+			if (v==Stel_KEYDOWN && k==StelKey_DOWN)
 			{
 				if (Branch::current!=--Branch::childs.end()) ++Branch::current;
 				return true;
 			}
-			if (v==S_TUI_PRESSED && (k==SDLK_RIGHT || k==SDLK_RETURN))
+			if (v==Stel_KEYDOWN && (k==StelKey_RIGHT || k==StelKey_RETURN))
 			{
 				if ((*Branch::current)->isEditable()) isEditing = true;
 				return true;
 			}
-			if (v==S_TUI_PRESSED && (k==SDLK_LEFT || k==SDLK_ESCAPE))
+			if (v==Stel_KEYDOWN && (k==StelKey_LEFT || k==StelKey_ESCAPE))
 			{
 				isNavigating = false;
 				return true;
@@ -223,7 +223,7 @@ bool MenuBranch::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else
 	{
-		if (v==S_TUI_PRESSED && (k==SDLK_RIGHT || k==SDLK_RETURN))
+		if (v==Stel_KEYDOWN && (k==StelKey_RIGHT || k==StelKey_RETURN))
 		{
 			isNavigating = true;
 			return true;
@@ -248,12 +248,12 @@ MenuBranch_item::MenuBranch_item(const wstring& s) : Branch(), label(s), isEditi
 {
 }
 
-bool MenuBranch_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool MenuBranch_item::onKey(Uint16 k, Uint8 v)
 {
 	if (isEditing)
 	{
 		if ((*Branch::current)->onKey(k, v)) return true;
-		if (v==S_TUI_PRESSED && (k==SDLK_LEFT || k==SDLK_ESCAPE || k==SDLK_RETURN))
+		if (v==Stel_KEYDOWN && (k==StelKey_LEFT || k==StelKey_ESCAPE || k==StelKey_RETURN))
 		{
 			isEditing = false;
 			return true;
@@ -262,24 +262,24 @@ bool MenuBranch_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else
 	{
-		if (v==S_TUI_PRESSED && k==SDLK_UP)
+		if (v==Stel_KEYDOWN && k==StelKey_UP)
 		{
 			if (Branch::current!=Branch::childs.begin()) --Branch::current;
 			if (!onChangeCallback.empty()) onChangeCallback();
 			return true;
 		}
-		if (v==S_TUI_PRESSED && k==SDLK_DOWN)
+		if (v==Stel_KEYDOWN && k==StelKey_DOWN)
 		{
 			if (Branch::current!=--Branch::childs.end()) ++Branch::current;
 			if (!onChangeCallback.empty()) onChangeCallback();
 			return true;
 		}
-		if (v==S_TUI_PRESSED && (k==SDLK_RIGHT || k==SDLK_RETURN))
+		if (v==Stel_KEYDOWN && (k==StelKey_RIGHT || k==StelKey_RETURN))
 		{
 			if ((*Branch::current)->isEditable()) isEditing = true;
 			return true;
 		}
-		if (v==S_TUI_PRESSED && (k==SDLK_LEFT || k==SDLK_ESCAPE))
+		if (v==Stel_KEYDOWN && (k==StelKey_LEFT || k==StelKey_ESCAPE))
 		{
 			return false;
 		}
@@ -304,9 +304,9 @@ Boolean_item::Boolean_item(bool init_state, const wstring& _label, const wstring
 	string_disabled = _string_disabled;
 }
 
-bool Boolean_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Boolean_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_PRESSED && (k==SDLK_UP || k==SDLK_DOWN) )
+	if (v==Stel_KEYDOWN && (k==StelKey_UP || k==StelKey_DOWN) )
 	{
 		state = !state;
 		if (!onChangeCallback.empty()) onChangeCallback();
@@ -324,20 +324,20 @@ wstring Boolean_item::getString(void)
 
 wstring Integer::getString(void)
 {
-	return (active ? start_active : L"") + StelUtility::doubleToWstring(value) + (active ? stop_active : L"");
+	return (active ? start_active : L"") + StelUtils::doubleToWstring(value) + (active ? stop_active : L"");
 }
 
 wstring Decimal::getString(void)
 {
-	return (active ? start_active : L"") + StelUtility::doubleToWstring(value) + (active ? stop_active : L"");
+	return (active ? start_active : L"") + StelUtils::doubleToWstring(value) + (active ? stop_active : L"");
 }
 
-bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Integer_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_RELEASED) return false;
+	if (v==Stel_KEYUP) return false;
 	if (!numInput)
 	{
-		if (k==SDLK_UP)
+		if (k==StelKey_UP)
 		{
 			++value;
 			if (value>mmax)
@@ -348,7 +348,7 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 			if (!onChangeCallback.empty()) onChangeCallback();
 			return true;
 		}
-		if (k==SDLK_DOWN)
+		if (k==StelKey_DOWN)
 		{
 			--value;
 			if (value<mmin)
@@ -360,8 +360,8 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 
-		if (k==SDLK_0 || k==SDLK_1 || k==SDLK_2 || k==SDLK_3 || k==SDLK_4 || k==SDLK_5 ||
-			k==SDLK_6 || k==SDLK_7 || k==SDLK_8 || k==SDLK_9 || k==SDLK_MINUS)
+		if (k==StelKey_0 || k==StelKey_1 || k==StelKey_2 || k==StelKey_3 || k==StelKey_4 || k==StelKey_5 ||
+			k==StelKey_6 || k==StelKey_7 || k==StelKey_8 || k==StelKey_9 || k==StelKey_MINUS)
 		{
 			// Start editing with numerical numbers
 			numInput = true;
@@ -376,7 +376,7 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else	// numInput == true
 	{
-		if (k==SDLK_RETURN)
+		if (k==StelKey_RETURN)
 		{
 			numInput=false;
 			wistringstream is(strInput);
@@ -387,29 +387,29 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 
-		if (k==SDLK_UP)
+		if (k==StelKey_UP)
 		{
 			wistringstream is(strInput);
 			is >> value;
 			++value;
 			if (value>mmax) value = mmax;
 			if (value<mmin) value = mmin;
-			strInput = StelUtility::doubleToWstring(value);
+			strInput = StelUtils::doubleToWstring(value);
 			return true;
 		}
-		if (k==SDLK_DOWN)
+		if (k==StelKey_DOWN)
 		{
 			wistringstream is(strInput);
 			is >> value;
 			--value;
 			if (value>mmax) value = mmax;
 			if (value<mmin) value = mmin;
-			strInput = StelUtility::doubleToWstring(value);
+			strInput = StelUtils::doubleToWstring(value);
 			return true;
 		}
 
-		if (k==SDLK_0 || k==SDLK_1 || k==SDLK_2 || k==SDLK_3 || k==SDLK_4 || k==SDLK_5 ||
-			k==SDLK_6 || k==SDLK_7 || k==SDLK_8 || k==SDLK_9 || k==SDLK_MINUS)
+		if (k==StelKey_0 || k==StelKey_1 || k==StelKey_2 || k==StelKey_3 || k==StelKey_4 || k==StelKey_5 ||
+			k==StelKey_6 || k==StelKey_7 || k==StelKey_8 || k==StelKey_9 || k==StelKey_MINUS)
 		{
 			// The user was already editing
 			char c = k;
@@ -417,7 +417,7 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 
-		if (k==SDLK_ESCAPE)
+		if (k==StelKey_ESCAPE)
 		{
 			numInput=false;
 			return false;
@@ -431,15 +431,15 @@ bool Integer_item::onKey(Uint16 k, S_TUI_VALUE v)
 wstring Integer_item::getString(void)
 {
 	if (numInput) return label + (active ? start_active : L"") + strInput + (active ? stop_active : L"");
-	else return label + (active ? start_active : L"") + StelUtility::doubleToWstring(value) + (active ? stop_active : L"");
+	else return label + (active ? start_active : L"") + StelUtils::doubleToWstring(value) + (active ? stop_active : L"");
 }
 
-bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Decimal_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_RELEASED) return false;
+	if (v==Stel_KEYUP) return false;
 	if (!numInput)
 	{
-		if (k==SDLK_UP)
+		if (k==StelKey_UP)
 		{
 			value+=delta;
 			if (value>mmax)
@@ -450,7 +450,7 @@ bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
 			if (!onChangeCallback.empty()) onChangeCallback();
 			return true;
 		}
-		if (k==SDLK_DOWN)
+		if (k==StelKey_DOWN)
 		{
 			value-=delta;
 			if (value<mmin)
@@ -462,8 +462,8 @@ bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 
-		if (k==SDLK_0 || k==SDLK_1 || k==SDLK_2 || k==SDLK_3 || k==SDLK_4 || k==SDLK_5 ||
-			k==SDLK_6 || k==SDLK_7 || k==SDLK_8 || k==SDLK_9 || k==SDLK_PERIOD || k==SDLK_MINUS)
+		if (k==StelKey_0 || k==StelKey_1 || k==StelKey_2 || k==StelKey_3 || k==StelKey_4 || k==StelKey_5 ||
+			k==StelKey_6 || k==StelKey_7 || k==StelKey_8 || k==StelKey_9 || k==StelKey_PERIOD || k==StelKey_MINUS)
 		{
 			// Start editing with numerical numbers
 			numInput = true;
@@ -477,7 +477,7 @@ bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else	// numInput == true
 	{
-		if (k==SDLK_RETURN || k==SDLK_LEFT)
+		if (k==StelKey_RETURN || k==StelKey_LEFT)
 		{
 			numInput=false;
 			wistringstream is(strInput);
@@ -488,29 +488,29 @@ bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return false;
 		}
 
-		if (k==SDLK_UP)
+		if (k==StelKey_UP)
 		{
 			wistringstream is(strInput);
 			is >> value;
 			value+=delta;
 			if (value>mmax) value = mmax;
 			if (value<mmin) value = mmin;
-			strInput = StelUtility::doubleToWstring(value);
+			strInput = StelUtils::doubleToWstring(value);
 			return true;
 		}
-		if (k==SDLK_DOWN)
+		if (k==StelKey_DOWN)
 		{
 			wistringstream wistemp(strInput);
 			wistemp >> value;
 			value-=delta;
 			if (value>mmax) value = mmax;
 			if (value<mmin) value = mmin;
-			strInput = StelUtility::doubleToWstring(value);
+			strInput = StelUtils::doubleToWstring(value);
 			return true;
 		}
 
-		if (k==SDLK_0 || k==SDLK_1 || k==SDLK_2 || k==SDLK_3 || k==SDLK_4 || k==SDLK_5 ||
-			k==SDLK_6 || k==SDLK_7 || k==SDLK_8 || k==SDLK_9 || k==SDLK_PERIOD || k==SDLK_MINUS)
+		if (k==StelKey_0 || k==StelKey_1 || k==StelKey_2 || k==StelKey_3 || k==StelKey_4 || k==StelKey_5 ||
+			k==StelKey_6 || k==StelKey_7 || k==StelKey_8 || k==StelKey_9 || k==StelKey_PERIOD || k==StelKey_MINUS)
 		{
 			// The user was already editing
 			wchar_t c = (wchar_t)k;
@@ -518,7 +518,7 @@ bool Decimal_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 
-		if (k==SDLK_ESCAPE)
+		if (k==StelKey_ESCAPE)
 		{
 			numInput=false;
 			return false;
@@ -534,7 +534,7 @@ wstring Decimal_item::getString(void)
 	// Can't directly write value in os because there is a float precision limit bug..
 	static char tempstr[16];
 	sprintf(tempstr,"%.2f", value);
-	wstring vstr = StelUtility::stringToWstring(tempstr);
+	wstring vstr = StelUtils::stringToWstring(tempstr);
 
 	if (numInput) return label + (active ? start_active : L"") + strInput + (active ? stop_active : L"");
 	else return label + (active ? start_active : L"") + vstr + (active ? stop_active : L"");
@@ -566,9 +566,9 @@ Time_item::~Time_item()
 	delete s;
 }
 
-bool Time_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Time_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_RELEASED) return false;
+	if (v==Stel_KEYUP) return false;
 
 	if (current_edit->onKey(k,v))
 	{
@@ -579,12 +579,12 @@ bool Time_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else
 	{
-		if (k==SDLK_ESCAPE)
+		if (k==StelKey_ESCAPE)
 		{
 			return false;
 		}
 
-		if (k==SDLK_RIGHT)
+		if (k==StelKey_RIGHT)
 		{
 			if (current_edit==y) current_edit=m;
 			else if (current_edit==m) current_edit=d;
@@ -594,7 +594,7 @@ bool Time_item::onKey(Uint16 k, S_TUI_VALUE v)
 			else if (current_edit==s) current_edit=y;
 			return true;
 		}
-		if (k==SDLK_LEFT)
+		if (k==StelKey_LEFT)
 		{
 			if (current_edit==y) current_edit=s;
 			else if (current_edit==m) current_edit=y;
@@ -756,9 +756,9 @@ Time_zone_item::Time_zone_item(const string& zonetab_file, const wstring& _label
 	current_edit=&continents_names;
 }
 
-bool Time_zone_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Time_zone_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_RELEASED) return false;
+	if (v==Stel_KEYUP) return false;
 
 	if (current_edit->onKey(k,v))
 	{
@@ -767,18 +767,18 @@ bool Time_zone_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else
 	{
-		if (k==SDLK_ESCAPE)
+		if (k==StelKey_ESCAPE)
 		{
 			return false;
 		}
 
-		if (k==SDLK_RIGHT)
+		if (k==StelKey_RIGHT)
 		{
 			if (current_edit==&continents_names) current_edit = &continents[continents_names.getCurrent()];
 			else current_edit=&continents_names;
 			return true;
 		}
-		if (k==SDLK_LEFT)
+		if (k==StelKey_LEFT)
 		{
 			if (current_edit==&continents_names) return false;
 			else current_edit = &continents_names;
@@ -795,8 +795,8 @@ wstring Time_zone_item::getString(void)
 	if (current_edit==&continents_names && active){s1[0] = start_active; s2[0] = stop_active;}
 	if (current_edit!=&continents_names && active){s1[1] = start_active; s2[1] = stop_active;}
 
-	return label + s1[0] + StelUtility::stringToWstring(continents_names.getCurrent()) + s2[0] + L"/" + s1[1] +
-		StelUtility::stringToWstring(continents[continents_names.getCurrent()].getCurrent()) + s2[1];
+	return label + s1[0] + StelUtils::stringToWstring(continents_names.getCurrent()) + s2[0] + L"/" + s1[1] +
+		StelUtils::stringToWstring(continents[continents_names.getCurrent()].getCurrent()) + s2[1];
 }
 
 string Time_zone_item::gettz(void) // should be const but gives a boring error...
@@ -834,9 +834,9 @@ wstring Action_item::getString(void)
 	}
 }
 
-bool Action_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Action_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_PRESSED && k==SDLK_RETURN)
+	if (v==Stel_KEYDOWN && k==StelKey_RETURN)
 	{
 		// Call the callback if enter is pressed
 		if (!onChangeCallback.empty()) onChangeCallback();
@@ -862,9 +862,9 @@ wstring ActionConfirm_item::getString(void)
 	else return label + string_prompt1;
 }
 
-bool ActionConfirm_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool ActionConfirm_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_PRESSED && k==SDLK_RETURN)
+	if (v==Stel_KEYDOWN && k==StelKey_RETURN)
 	{
 		if (isConfirming)
 		{
@@ -879,7 +879,7 @@ bool ActionConfirm_item::onKey(Uint16 k, S_TUI_VALUE v)
 			return true;
 		}
 	}
-	if (v==S_TUI_PRESSED && ( k==SDLK_ESCAPE || k==SDLK_LEFT) )
+	if (v==Stel_KEYDOWN && ( k==StelKey_ESCAPE || k==StelKey_LEFT) )
 	{
 		if (isConfirming)
 		{
@@ -911,9 +911,9 @@ Vector_item::~Vector_item()
 	delete c;
 }
 
-bool Vector_item::onKey(Uint16 k, S_TUI_VALUE v)
+bool Vector_item::onKey(Uint16 k, Uint8 v)
 {
-	if (v==S_TUI_RELEASED) return false;
+	if (v==Stel_KEYUP) return false;
 
 	if (current_edit->onKey(k,v))
 	{
@@ -923,19 +923,19 @@ bool Vector_item::onKey(Uint16 k, S_TUI_VALUE v)
 	}
 	else
 	{
-		if (k==SDLK_ESCAPE)
+		if (k==StelKey_ESCAPE)
 		{
 			return false;
 		}
 
-		if (k==SDLK_RIGHT)
+		if (k==StelKey_RIGHT)
 		{
 			if (current_edit==a) current_edit=b;
 			else if (current_edit==b) current_edit=c;
 			else if (current_edit==c) current_edit=a;
 			return true;
 		}
-		if (k==SDLK_LEFT)
+		if (k==StelKey_LEFT)
 		{
 			if (current_edit==a) current_edit=c;
 			else if (current_edit==c) current_edit=b;
@@ -967,5 +967,5 @@ wstring Vector_item::getString(void)
 	wstring MultiSet_item<string>::getString(void)
 	{
 		if (current==items.end()) return label;
-		return label + (active ? start_active : L"") + StelUtility::stringToWstring(*current) + (active ? stop_active : L"");
+		return label + (active ? start_active : L"") + StelUtils::stringToWstring(*current) + (active ? stop_active : L"");
 	}
