@@ -23,11 +23,10 @@
 #ifndef _SCRIPT_H_
 #define _SCRIPT_H_
 
-#include <iostream>
+using namespace std;
+
 #include <fstream>
 #include <string>
-#include "stel_command_interface.h"
-
 
 class Script
 {
