@@ -24,21 +24,27 @@
 #ifndef _SCRIPT_MGR_H_
 #define _SCRIPT_MGR_H_
 
-#include <iostream>
+using namespace std;
+
+#include <string>
 #include <fstream>
-#include "stel_command_interface.h"
-#include "script.h"
+#include "StelModule.hpp"
 
 // predeclaration
 class StelCommandInterface;
 class Script;
 
-class ScriptMgr
+class ScriptMgr : public StelModule
 {
 
  public:
-  ScriptMgr(StelCommandInterface * command_interface, string _data_dir);
-  ~ScriptMgr();
+  ScriptMgr(StelCommandInterface * command_interface);
+  virtual ~ScriptMgr();
+  virtual string getModuleID() const { return "script_mgr"; }
+  
+  virtual void init(const InitParser& conf, LoadingBar& lb) {return;}
+  virtual double draw(Projector* prj, const Navigator * nav, ToneReproducer* eye) {return 0;}
+  
   bool play_script(string script_file, string script_path);
   bool play_startup_script();
   void cancel_script();  // stop playing current script
@@ -50,7 +56,7 @@ class ScriptMgr
   bool is_playing() { return playing; };     // is a script playing? 
   bool is_paused() { return play_paused; };     // is a script paused?
   bool is_recording() { return recording; };    // is a script being recorded? 
-  void update(int delta_time);  // execute commands in running script
+  virtual void update(double delta_time);  // execute commands in running script
   string get_script_list(string directory);  // get list of scripts in a directory
   string get_script_path();
   string get_record_filename() { return rec_filename; }  // file record is writing to
@@ -58,6 +64,8 @@ class ScriptMgr
   bool get_allow_ui() { return allow_ui; }
   void set_gui_debug(bool _gdebug) { gui_debug = _gdebug; }  // Should script errors be shown onscreen?
   bool get_gui_debug() { return gui_debug; }
+  void set_removable_media_path(const string& path) { RemoveableScriptDirectory = path; };
+  const string& get_removable_media_path(void) { return RemoveableScriptDirectory; };
 
  private:
 
@@ -73,7 +81,6 @@ class ScriptMgr
   string rec_filename;
   string RemoveableScriptDirectory;
   bool RemoveableDirectoryMounted;
-  string DataDir;  
   bool allow_ui;    // Allow user interface to function during scripts 
                     // (except for time related keys which control script playback)
   bool gui_debug;
