@@ -25,11 +25,9 @@
 #define _STEL_COMMAND_INTERFACE_H_
 
 #include "command_interface.h"
-#include "stel_core.h"
-#include "stelapp.h"
-#include "stel_utility.h"
+#include "StelUtils.hpp"
 #include "script_mgr.h"
-#include "audio.h"
+#include "StelModule.hpp"
 
 using namespace std;
 
@@ -37,23 +35,30 @@ using namespace std;
 class StelCore;
 class StelApp;
 
-class StelCommandInterface : CommandInterface
+class StelCommandInterface : CommandInterface, public StelModule
 {
 
  public:
   StelCommandInterface(StelCore * core, StelApp * app);
   virtual ~StelCommandInterface();
+  virtual string getModuleID() const { return "command_interface"; }
+  virtual void init(const InitParser& conf, LoadingBar& lb) {return;}
+  virtual double draw(Projector* prj, const Navigator * nav, ToneReproducer* eye) {return 0;}
+  
   virtual int execute_command(string commandline);
   virtual int execute_command(string command, double arg);
   virtual int execute_command(string command, int arg);
   virtual int execute_command(string command, unsigned long int &wait, bool trusted);
   virtual int set_flag(string name, string value, bool &newval, bool trusted);
-  void update(int delta_time);
+  virtual void update(double delta_time);
 
  private:
+	int FlagTimePause;
+	double temp_time_velocity;			// Used to store time speed while in pause
+	
   StelCore * stcore;
   StelApp * stapp;
-  Audio * audio;  // for audio track from script
+  class Audio * audio;  // for audio track from script
 };
 
 
