@@ -18,16 +18,13 @@
  */
 
 // Class which handles a stellarium User Interface
-// TODO : get rid of the SDL macro def and types
-// need the creation of an interface between s_gui and SDL
 
 #ifndef _STEL_UI_H
 #define _STEL_UI_H
 
-#include "stellarium.h"
+#include <config.h>
 #include "s_gui.h"
 #include "s_tui.h"
-#include "stel_command_interface.h"
 
 #define TUI_SCRIPT_MSG "Select and exit to run."
 
@@ -37,42 +34,53 @@ using namespace s_gui;
 class StelApp;
 class StelCore;
 class StelCommandInterface;
+class InitParser;
+class Planet;
+class Projector;
+class Navigator;
+class ToneReproducer;
 
 class StelUI
 {
 friend class StelCommandInterface;
-friend class StelApp;
+
 public:
 	StelUI(StelCore *, StelApp * _app);	// Create a stellarium ui. Need to call init() before use
     virtual ~StelUI();		// Delete the ui
+    
+    virtual double draw(Projector *prj, const Navigator *nav, ToneReproducer *eye);
+	virtual void update(double deltaTime);
+    
 	void init(const InitParser& conf);		// Initialize the ui.
-	void draw(void);		// Display the ui
+	void drawTui(void);		// Display the ui
+	void drawGui(void);		// Display the ui
 	void gui_update_widgets(int delta_time);		// Update changing values
 
 	void draw_gravity_ui(void);	// Draw simple gravity text ui.
 
 	// Handle mouse clics
-	int handle_clic(Uint16 x, Uint16 y, S_GUI_VALUE button, S_GUI_VALUE state);
+	int handle_clic(Uint16 x, Uint16 y, Uint8 button, Uint8 state, StelMod mod);
 	// Handle mouse move
-	int handle_move(int x, int y);
+	int handle_move(int x, int y, StelMod mod);
 	// Handle key press and release
-	int handle_keys(SDLKey key, SDLMod mod, Uint16 unicode, S_GUI_VALUE state);
+	int handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state);
 
 	// Text UI
 	void init_tui(void);
 	void localizeTui(void);
 	void draw_tui(void);		// Display the tui
-	int handle_keys_tui(Uint16 key, s_tui::S_TUI_VALUE state);
+	int handle_keys_tui(Uint16 key, Uint8 state);
+	int handle_keysGUI(StelKey key, StelMod mod, Uint16 unicode, Uint8 state);
 	// Update all the tui widgets with values taken from the core parameters
 	void tui_update_widgets(void);
 	void tuiUpdateIndependentWidgets(void); // For widgets that aren't tied directly to current settings
 	void show_message(wstring _message, int _time_out=0);
     void setStarAutoComplete(vector<wstring> _autoComplete ) { star_edit->setAutoCompleteOptions(_autoComplete);}
     void setTitleObservatoryName(const wstring& name);
+    void setTitle(const wstring& title);
     wstring getTitleWithAltitude(void);
-    bool isInitialised(void) { return initialised; }
 
-    void setColorScheme(const string& skinFile, const string& section);
+    void setColorScheme(const InitParser& conf, const string& section);
 	double getMouseCursorTimeout() { return MouseCursorTimeout; }
 
 	bool getFlagShowGravityUi() { return FlagShowGravityUi; }
@@ -80,22 +88,45 @@ public:
 	bool getFlagShowTuiShortObjInfo() { return FlagShowTuiShortObjInfo; }
 
 	// Whether tui menu is currently displayed
-	void setFlagShowTuiMenu(const bool flag);
+	void setFlagShowTuiMenu(bool flag);
 	bool getFlagShowTuiMenu() { return FlagShowTuiMenu; }
 
+	void setFlagShowTime(int b) {FlagShowTime=b;}
+	void setFlagShowFPS(int b) {FlagShowFps=b;}
+	void setFlagShowFov(int b) {FlagShowFov=b;}
+	
+	void setFlagShowFlagButtons(bool b);
+	
+	void setFlagShowConfigWin(bool b);
+	bool getFlagShowConfigWin() const {return config_win->getVisible();}
+	
+	// for use by TUI
+	void saveCurrentConfig(const string& confFile);
+	
+	void updateInfoSelectString(void);
+	
+	//! Resize the UI desktop to a new window size
+	void resize();
 
+	//! Set day key mode (calendar, sidereal)
+	void setDayKeyMode(const string dayMode);
+
+	//! Get day key mode (calendar, sidereal)
+	string getDayKeyMode();
+	
+	//! Update the planet map in the configuration
+	//! @param englishName The english name of the new planet to set in the map widget 
+	void updatePlanetMap(const string& englishName);
+	
 private:
 	StelCore * core;		// The main core can be accessed because StelUI is a friend class (TODO fix that)
 	StelApp * app;			// The main application instance
 	
 	bool initialised;
-	s_font * baseFont;		// The standard font
-	s_font * courierFont;	// The standard fixed size font
-	s_font * tuiFont;		// The standard tui font - separate from gui so can reload on the fly
-	s_texture * baseTex;	// The standard fill texture
-	s_texture * flipBaseTex;	// The standard fill texture
-	s_texture * tex_up;		// Up arrow texture
-	s_texture * tex_down;	// Down arrow texture
+	STextureSP baseTex;	// The standard fill texture
+	STextureSP flipBaseTex;	// The standard fill texture
+	STextureSP tex_up;		// Up arrow texture
+	STextureSP tex_down;	// Down arrow texture
 
 	// Flags and variables (moved from StelCore)
 	int FlagShowTopBar;
@@ -110,11 +141,11 @@ private:
     int FlagConfig;
     int FlagSearch;
 	int FlagShowSelectedObjectInfo;
-	int FlagShowScriptBar;	
-	float BaseFontSize;
-	string BaseFontName;
-	float BaseCFontSize;
-	string BaseCFontName;
+	int FlagShowScriptBar;
+	
+	double baseFontSize;
+	double baseCFontSize;
+	SFont* tuiFont;
 	
 	// Text UI
 	bool FlagEnableTuiMenu;
@@ -135,7 +166,8 @@ private:
 	Label * top_bar_fps_lbl;
 	Label * top_bar_appName_lbl;
 	Label * top_bar_fov_lbl;
-	Component* createTopBar(void);
+	Component* createTopBar(SFont& baseFont);
+	Planet* topBarLastPlanet;	
 	void updateTopBar(void);
 
 	// Flags buttons (the buttons in the bottom left corner)
@@ -172,7 +204,7 @@ private:
 	void bt_flag_ctrOnMouseInOut(void);
 	void cbr(void);
 
-	// Tile control buttons
+	// Time control buttons
 	FilledContainer * bt_time_control_ctr;
 	FlagButton * bt_dec_time_speed;
 	FlagButton * bt_real_time_speed;
@@ -193,7 +225,6 @@ private:
 	// The TextLabel displaying the infos about the selected object
 	Container * info_select_ctr;
 	TextLabel * info_select_txtlbl;
-	void updateInfoSelectString(void);
 
 	// The window containing the info (licence)
 	StdBtWin * licence_win;
@@ -203,7 +234,7 @@ private:
 	// The window containing the help info
 	StdBtWin * help_win;
 	TextLabel * help_txtlbl;
-	Component* createHelpWindow(void);
+	Component* createHelpWindow(SFont& courierFont);
 	void help_win_hideBtCallback(void);
 
 	// window for transient messages
@@ -212,12 +243,12 @@ private:
 
 	// The window managing the configuration
 	StdBtWin* config_win;
-	Component* createConfigWindow(void);
+	Component* createConfigWindow(SFont& courierFont);
 	void config_win_hideBtCallback(void);
 
 	TabContainer * config_tab_ctr;
 
-	void load_cities(const string & fileName);
+	void load_cities(const string & planetEnglishName);
 	vector<City*> cities;
 
 	// The window managing the search - Tony
@@ -274,6 +305,7 @@ private:
 	Label *lblMapPointer;
 	FloatIncDec* lat_incdec, * long_incdec;
 	IntIncDec* alt_incdec;
+	Planet* mapLastPlanet;
 	void setObserverPositionFromMap(void);
 	void setCityFromMap(void);
 	void setObserverPositionFromIncDec(void);
@@ -292,6 +324,7 @@ private:
 	// Video Options
 	StringList* projection_sl;
 	LabeledCheckBox* disk_viewport_cbx;
+	LabeledCheckBox* viewport_distorter_cbx;
 	ListBox* screen_size_sl;
 	void setVideoOption(void);
 	void updateVideoVariables(void);
@@ -308,6 +341,10 @@ private:
 	void saveLandscapeOption(void);
 	Label* landscape_authorlb;
 	TextLabel* landscape_descriptionlb;
+	Label* landscapePlanetLb;
+	Label* landscapeLocationLb;
+	LabeledCheckBox* locationFromLandscapeCheck;
+	void setLandscapeUpdatesLocation(void);
 	
 	// Language options
 	ListBox* language_lb;
@@ -317,9 +354,7 @@ private:
 	void setSkyLanguage(void);
 	void setSkyCulture(void);
 
-	// Mouse control options
-	bool is_dragging, has_dragged;
-	int previous_x, previous_y;
+	string dayKeyMode;  // whether day keys should use calendar or sidereal days
 
 	////////////////////////////////////////////////////////////////////////////
 	// Text UI components
@@ -344,6 +379,7 @@ private:
 	// 2. Time & Date
 	s_tui::Time_zone_item* tui_time_settmz;
 	s_tui::Time_item* tui_time_skytime;
+	s_tui::MultiSet2_item<wstring>* tui_time_day_key;
 	s_tui::Time_item* tui_time_presetskytime;
 	s_tui::MultiSet2_item<wstring>* tui_time_startuptime;
 	s_tui::MultiSet_item<wstring>* tui_time_displayformat;
@@ -359,6 +395,7 @@ private:
 	s_tui::Decimal_item* tui_star_labelmaxmag;
 	s_tui::Decimal_item* tui_stars_twinkle;
 	s_tui::Decimal_item* tui_star_magscale;
+	s_tui::Decimal_item* tui_star_limitingmag;
 	
 	//  Colors
 	s_tui::Vector_item* tui_colors_const_line_color;
@@ -378,6 +415,7 @@ private:
 	s_tui::Decimal_item* tui_colors_const_art_intensity;
 
 	// 5. Effects
+	s_tui::Decimal_item* tui_effect_light_pollution;
 	s_tui::MultiSet_item<wstring>* tui_effect_landscape;
 	s_tui::Boolean_item* tui_effect_pointobj;
 	s_tui::Decimal_item* tui_effect_object_scale;
@@ -386,6 +424,7 @@ private:
 	s_tui::Decimal_item* tui_effect_nebulae_label_magnitude;
 	s_tui::Boolean_item* tui_effect_manual_zoom;
 	s_tui::Decimal_item* tui_effect_cursor_timeout;
+	s_tui::Boolean_item* tui_effect_landscape_sets_location;
 
 	// 6. Scripts
 	s_tui::MultiSet_item<wstring>* tui_scripts_local;
@@ -421,12 +460,18 @@ private:
 	void tui_cb_sky_time();        // change effect parameters
 	void tui_cb_change_color();        // change colors
 	void tui_cb_location_change_planet();  // change planet of observer
+	void tui_cb_day_key();  // change length of time for day keys
 
 	// Parse a file of type /usr/share/zoneinfo/zone.tab
 	s_tui::MultiSet_item<wstring>* create_tree_from_time_zone_file(const string& zonetab);
 
 	bool ScriptDirectoryRead;
 	double MouseTimeLeft;  // for cursor timeout (seconds)
+	
+	// Script related
+	string SelectedScript;  // script filename (without directory) selected in a UI to run when exit UI
+	string SelectedScriptDirectory;  // script directory for same
+	
 };
 
 #endif  //_STEL_UI_H
